#
# Generated by TigerShark.tools.convertPyX12 on 2014-06-30 18:14:56.440530
#
from tigershark.X12.parse import Message, Loop, Segment, Composite, Element, Properties


parsed_271_2100A = Loop(
    u'2100A',
    Properties(
        position=u'0300', looptype='', repeat=u'1', req_sit=u'R',
        desc=u'Information Source Name'),
    Segment(
        u'NM1',
        Properties(
            syntax=u'P0809 C1110 C1203', position=u'0300', req_sit=u'R', repeat=u'1',
            desc=u'Information Source Name'),
        Element(
            u'NM101', Properties(
                desc=u'Entity Identifier Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'2B', u'36', u'GP', u'P5', u'PR'])
        ),
        Element(
            u'NM102', Properties(
                desc=u'Entity Type Qualifier', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=2,
                codes=[u'1', u'2'])
        ),
        Element(
            u'NM103', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'R',
                data_type=(u'AN', u'1', u'60'), position=3,
                codes=[])
        ),
        Element(
            u'NM104',
            Properties(
                desc=u'Name First', req_sit=u'S', data_type=(u'AN', u'1', u'35'),
                position=4,
                codes=[])
        ),
        Element(
            u'NM105',
            Properties(
                desc=u'Name Middle', req_sit=u'S', data_type=(u'AN', u'1', u'25'),
                position=5,
                codes=[])
        ),
        Element(
            u'NM106',
            Properties(
                desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN', u'1', u'10'),
                position=6,
                codes=[])
        ),
        Element(
            u'NM107',
            Properties(
                desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN', u'1', u'10'),
                position=7,
                codes=[])
        ),
        Element(
            u'NM108', Properties(
                desc=u'Identification Code Qualifier', req_sit=u'R',
                data_type=(u'ID', u'1', u'2'), position=8,
                codes=[u'24', u'46', u'FI', u'NI', u'PI', u'XV', u'XX'])
        ),
        Element(
            u'NM109', Properties(
                desc=u'Identification Code', req_sit=u'R',
                data_type=(u'AN', u'2', u'80'), position=9,
                codes=[])
        ),
        Element(
            u'NM110', Properties(
                desc=u'Entity Relationship Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=10,
                codes=[])
        ),
        Element(
            u'NM111', Properties(
                desc=u'Entity Identifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'3'), position=11,
                codes=[])
        ),
        Element(
            u'NM112', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'N',
                data_type=(u'AN', u'1', u'60'), position=12,
                codes=[])
        ),
    ),
    Segment(
        u'PER',
        Properties(
            syntax=u'P0304 P0506 P0708', position=u'0800', req_sit=u'S', repeat=u'3',
            desc=u'Information Source Contact Information'),
        Element(
            u'PER01', Properties(
                desc=u'Contact Function Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=1,
                codes=[u'IC'])
        ),
        Element(
            u'PER02', Properties(
                desc=u'Name', req_sit=u'S', data_type=(u'AN', u'1', u'60'),
                position=2,
                codes=[])
        ),
        Element(
            u'PER03', Properties(
                desc=u'Communication Number Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'ED', u'EM', u'FX', u'TE', u'UR'])
        ),
        Element(
            u'PER04', Properties(
                desc=u'Communication Number', req_sit=u'S',
                data_type=(u'AN', u'1', u'256'), position=4,
                codes=[])
        ),
        Element(
            u'PER05', Properties(
                desc=u'Communication Number Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=5,
                codes=[u'ED', u'EM', u'EX', u'FX', u'TE', u'UR'])
        ),
        Element(
            u'PER06', Properties(
                desc=u'Communication Number', req_sit=u'S',
                data_type=(u'AN', u'1', u'256'), position=6,
                codes=[])
        ),
        Element(
            u'PER07', Properties(
                desc=u'Communication Number Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=7,
                codes=[u'ED', u'EM', u'EX', u'FX', u'TE', u'UR'])
        ),
        Element(
            u'PER08', Properties(
                desc=u'Communication Number', req_sit=u'S',
                data_type=(u'AN', u'1', u'256'), position=8,
                codes=[])
        ),
        Element(
            u'PER09', Properties(
                desc=u'Contact Inquiry Reference', req_sit=u'N',
                data_type=(u'AN', u'1', u'20'), position=9,
                codes=[])
        ),
    ),
    Segment(
        u'AAA', Properties(
            syntax='', position=u'0850', req_sit=u'S', repeat=u'9',
            desc=u'Request Validation'),
        Element(
            u'AAA01', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'N', u'Y'])
        ),
        Element(
            u'AAA02', Properties(
                desc=u'Agency Qualifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'AAA03', Properties(
                desc=u'Reject Reason Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'04', u'41', u'42', u'79', u'80', u'T4'])
        ),
        Element(
            u'AAA04', Properties(
                desc=u'Follow-up Action Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'C', u'N', u'P', u'R', u'S', u'W', u'X', u'Y'])
        ),
    ),
)
parsed_271_2000A = Loop(
    u'2000A', Properties(
        position=u'0120', looptype='', repeat=u'>1', req_sit=u'R',
        desc=u'Information Source Level'),
    Segment(
        u'HL', Properties(
            syntax='', position=u'0100', req_sit=u'R', repeat=u'1',
            desc=u'Information Source Level'),
        Element(
            u'HL01', Properties(
                desc=u'Hierarchical ID Number', req_sit=u'R',
                data_type=(u'AN', u'1', u'12'), position=1,
                codes=[])
        ),
        Element(
            u'HL02', Properties(
                desc=u'Hierarchical Parent ID Number', req_sit=u'N',
                data_type=(u'AN', u'1', u'12'), position=2,
                codes=[])
        ),
        Element(
            u'HL03', Properties(
                desc=u'Hierarchical Level Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'2'), position=3,
                codes=[u'20'])
        ),
        Element(
            u'HL04', Properties(
                desc=u'Hierarchical Child Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'0', u'1'])
        ),
    ),
    Segment(
        u'AAA', Properties(
            syntax='', position=u'0250', req_sit=u'S', repeat=u'9',
            desc=u'Request Validation'),
        Element(
            u'AAA01', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'N', u'Y'])
        ),
        Element(
            u'AAA02', Properties(
                desc=u'Agency Qualifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'AAA03', Properties(
                desc=u'Reject Reason Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'04', u'41', u'42', u'79'])
        ),
        Element(
            u'AAA04', Properties(
                desc=u'Follow-up Action Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'C', u'N', u'P', u'R', u'S', u'Y'])
        ),
    ),
    parsed_271_2100A,
)
parsed_271_2100B = Loop(
    u'2100B', Properties(
        position=u'0300', looptype='', repeat=u'1', req_sit=u'R',
        desc=u'Information Receiver Name'),
    Segment(
        u'NM1',
        Properties(
            syntax=u'P0809 C1110 C1203', position=u'0300', req_sit=u'R', repeat=u'1',
            desc=u'Information Receiver Name'),
        Element(
            u'NM101', Properties(
                desc=u'Entity Identifier Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'1P', u'2B', u'36', u'80', u'FA', u'GP', u'P5',
                       u'PR'])
        ),
        Element(
            u'NM102', Properties(
                desc=u'Entity Type Qualifier', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=2,
                codes=[u'1', u'2'])
        ),
        Element(
            u'NM103', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'S',
                data_type=(u'AN', u'1', u'60'), position=3,
                codes=[])
        ),
        Element(
            u'NM104',
            Properties(
                desc=u'Name First', req_sit=u'S', data_type=(u'AN', u'1', u'35'),
                position=4,
                codes=[])
        ),
        Element(
            u'NM105',
            Properties(
                desc=u'Name Middle', req_sit=u'S', data_type=(u'AN', u'1', u'25'),
                position=5,
                codes=[])
        ),
        Element(
            u'NM106',
            Properties(
                desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN', u'1', u'10'),
                position=6,
                codes=[])
        ),
        Element(
            u'NM107',
            Properties(
                desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN', u'1', u'10'),
                position=7,
                codes=[])
        ),
        Element(
            u'NM108', Properties(
                desc=u'Identification Code Qualifier', req_sit=u'R',
                data_type=(u'ID', u'1', u'2'), position=8,
                codes=[u'24', u'34', u'FI', u'PI', u'PP', u'SV', u'XV',
                       u'XX'])
        ),
        Element(
            u'NM109', Properties(
                desc=u'Identification Code', req_sit=u'R',
                data_type=(u'AN', u'2', u'80'), position=9,
                codes=[])
        ),
        Element(
            u'NM110', Properties(
                desc=u'Entity Relationship Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=10,
                codes=[])
        ),
        Element(
            u'NM111', Properties(
                desc=u'Entity Identifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'3'), position=11,
                codes=[])
        ),
        Element(
            u'NM112', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'N',
                data_type=(u'AN', u'1', u'60'), position=12,
                codes=[])
        ),
    ),
    Segment(
        u'REF', Properties(
            syntax=u'R0203', position=u'0400', req_sit=u'S', repeat=u'9',
            desc=u'Information Receiver Additional Identification'),
        Element(
            u'REF01', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'0B', u'1C', u'1D', u'1J', u'4A', u'CT', u'EL',
                       u'EO', u'HPI', u'JD', u'N5', u'N7', u'Q4', u'SY',
                       u'TJ'])
        ),
        Element(
            u'REF02', Properties(
                desc=u'Reference Identification', req_sit=u'R',
                data_type=(u'AN', u'1', u'50'), position=2,
                codes=[])
        ),
        Element(
            u'REF03',
            Properties(
                desc=u'Description', req_sit=u'S', data_type=(u'AN', u'1', u'80'),
                position=3,
                codes=[])
        ),
        Composite(
            u'C040', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'04',
                desc=u'Reference Identifier'),
        ),
    ),
    Segment(
        u'N3', Properties(
            syntax='', position=u'0600', req_sit=u'S', repeat=u'1',
            desc=u'Information Receiver Address'),
        Element(
            u'N301', Properties(
                desc=u'Address Information', req_sit=u'R',
                data_type=(u'AN', u'1', u'55'), position=1,
                codes=[])
        ),
        Element(
            u'N302', Properties(
                desc=u'Address Information', req_sit=u'S',
                data_type=(u'AN', u'1', u'55'), position=2,
                codes=[])
        ),
    ),
    Segment(
        u'N4',
        Properties(
            syntax=u'E0207 C0605 C0704', position=u'0700', req_sit=u'S', repeat=u'1',
            desc=u'Information Receiver City, State, ZIP Code'),
        Element(
            u'N401',
            Properties(
                desc=u'City Name', req_sit=u'R', data_type=(u'AN', u'2', u'30'),
                position=1,
                codes=[])
        ),
        Element(
            u'N402', Properties(
                desc=u'State or Province Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'N403',
            Properties(
                desc=u'Postal Code', req_sit=u'S', data_type=(u'ID', u'3', u'15'),
                position=3,
                codes=[])
        ),
        Element(
            u'N404',
            Properties(
                desc=u'Country Code', req_sit=u'S', data_type=(u'ID', u'2', u'3'),
                position=4,
                codes=[])
        ),
        Element(
            u'N405', Properties(
                desc=u'Location Qualifier', req_sit=u'N',
                data_type=(u'ID', u'1', u'2'), position=5,
                codes=[])
        ),
        Element(
            u'N406', Properties(
                desc=u'Location Identifier', req_sit=u'N',
                data_type=(u'AN', u'1', u'30'), position=6,
                codes=[])
        ),
        Element(
            u'N407', Properties(
                desc=u'Country Subdivision Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=7,
                codes=[])
        ),
    ),
    Segment(
        u'AAA', Properties(
            syntax='', position=u'0850', req_sit=u'S', repeat=u'9',
            desc=u'Information Receiver Request Validation'),
        Element(
            u'AAA01', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'N', u'Y'])
        ),
        Element(
            u'AAA02', Properties(
                desc=u'Agency Qualifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'AAA03', Properties(
                desc=u'Reject Reason Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'15', u'41', u'43', u'44', u'45', u'46', u'47',
                       u'48', u'50', u'51', u'79', u'97', u'T4'])
        ),
        Element(
            u'AAA04', Properties(
                desc=u'Follow-up Action Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'C', u'N', u'R', u'S', u'W', u'X', u'Y'])
        ),
    ),
    Segment(
        u'PRV', Properties(
            syntax=u'P0203', position=u'0900', req_sit=u'S', repeat=u'1',
            desc=u'Information Receiver Provider Information'),
        Element(
            u'PRV01',
            Properties(
                desc=u'Provider Code', req_sit=u'R', data_type=(u'ID', u'1', u'3'),
                position=1,
                codes=[u'AD', u'AT', u'BI', u'CO', u'CV', u'H', u'HH', u'LA', u'OT',
                       u'P1', u'P2', u'PC', u'PE', u'R', u'RF', u'SB', u'SK',
                       u'SU'])
        ),
        Element(
            u'PRV02', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=2,
                codes=[u'PXC'])
        ),
        Element(
            u'PRV03', Properties(
                desc=u'Reference Identification', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=3,
                codes=[])
        ),
        Element(
            u'PRV04', Properties(
                desc=u'State or Province Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=4,
                codes=[])
        ),
        Composite(
            u'C035', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'05',
                desc=u'Provider Specialty Information'),
        ),
        Element(
            u'PRV06', Properties(
                desc=u'Provider Organization Code', req_sit=u'N',
                data_type=(u'ID', u'3', u'3'), position=6,
                codes=[])
        ),
    ),
)
parsed_271_2000B = Loop(
    u'2000B', Properties(
        position=u'0130', looptype='', repeat=u'>1', req_sit=u'S',
        desc=u'Information Receiver Level'),
    Segment(
        u'HL', Properties(
            syntax='', position=u'0100', req_sit=u'R', repeat=u'1',
            desc=u'Information Receiver Level'),
        Element(
            u'HL01', Properties(
                desc=u'Hierarchical ID Number', req_sit=u'R',
                data_type=(u'AN', u'1', u'12'), position=1,
                codes=[])
        ),
        Element(
            u'HL02', Properties(
                desc=u'Hierarchical Parent ID Number', req_sit=u'R',
                data_type=(u'AN', u'1', u'12'), position=2,
                codes=[])
        ),
        Element(
            u'HL03', Properties(
                desc=u'Hierarchical Level Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'2'), position=3,
                codes=[u'21'])
        ),
        Element(
            u'HL04', Properties(
                desc=u'Hierarchical Child Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'0', u'1'])
        ),
    ),
    parsed_271_2100B,
)
parsed_271_2120C = Loop(
    u'2120C', Properties(
        position=u'1800', looptype='', repeat=u'23', req_sit=u'S',
        desc=u'Subscriber Benefit Related Entity Name'),
    Segment(
        u'NM1',
        Properties(
            syntax=u'P0809 C1110 C1203', position=u'3400', req_sit=u'R', repeat=u'1',
            desc=u'Subscriber Benefit Related Entity Name'),
        Element(
            u'NM101', Properties(
                desc=u'Entity Identifier Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'13', u'1I', u'1P', u'2B', u'36', u'73', u'FA',
                       u'GP', u'GW', u'I3', u'IL', u'LR', u'OC', u'P3',
                       u'P4', u'P5', u'PR', u'PRP', u'SEP', u'TTP', u'VER',
                       u'VN', u'VY', u'X3', u'Y2'])
        ),
        Element(
            u'NM102', Properties(
                desc=u'Entity Type Qualifier', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=2,
                codes=[u'1', u'2'])
        ),
        Element(
            u'NM103', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'S',
                data_type=(u'AN', u'1', u'60'), position=3,
                codes=[])
        ),
        Element(
            u'NM104',
            Properties(
                desc=u'Name First', req_sit=u'S', data_type=(u'AN', u'1', u'35'),
                position=4,
                codes=[])
        ),
        Element(
            u'NM105',
            Properties(
                desc=u'Name Middle', req_sit=u'S', data_type=(u'AN', u'1', u'25'),
                position=5,
                codes=[])
        ),
        Element(
            u'NM106',
            Properties(
                desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN', u'1', u'10'),
                position=6,
                codes=[])
        ),
        Element(
            u'NM107',
            Properties(
                desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN', u'1', u'10'),
                position=7,
                codes=[])
        ),
        Element(
            u'NM108', Properties(
                desc=u'Identification Code Qualifier', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=8,
                codes=[u'24', u'34', u'46', u'FA', u'FI', u'II', u'MI',
                       u'NI', u'PI', u'PP', u'SV', u'XV', u'XX'])
        ),
        Element(
            u'NM109', Properties(
                desc=u'Identification Code', req_sit=u'S',
                data_type=(u'AN', u'2', u'80'), position=9,
                codes=[])
        ),
        Element(
            u'NM110', Properties(
                desc=u'Entity Relationship Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=10,
                codes=[u'01', u'02', u'27', u'41', u'48', u'65', u'72'])
        ),
        Element(
            u'NM111', Properties(
                desc=u'Entity Identifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'3'), position=11,
                codes=[])
        ),
        Element(
            u'NM112', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'N',
                data_type=(u'AN', u'1', u'60'), position=12,
                codes=[])
        ),
    ),
    Segment(
        u'N3', Properties(
            syntax='', position=u'3600', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Benefit Related Entity Address'),
        Element(
            u'N301', Properties(
                desc=u'Address Information', req_sit=u'R',
                data_type=(u'AN', u'1', u'55'), position=1,
                codes=[])
        ),
        Element(
            u'N302', Properties(
                desc=u'Address Information', req_sit=u'S',
                data_type=(u'AN', u'1', u'55'), position=2,
                codes=[])
        ),
    ),
    Segment(
        u'N4',
        Properties(
            syntax=u'E0207 C0605 C0704', position=u'3700', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Benefit Related Entity City, State, ZIP Code'),
        Element(
            u'N401',
            Properties(
                desc=u'City Name', req_sit=u'R', data_type=(u'AN', u'2', u'30'),
                position=1,
                codes=[])
        ),
        Element(
            u'N402', Properties(
                desc=u'State or Province Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'N403',
            Properties(
                desc=u'Postal Code', req_sit=u'S', data_type=(u'ID', u'3', u'15'),
                position=3,
                codes=[])
        ),
        Element(
            u'N404',
            Properties(
                desc=u'Country Code', req_sit=u'S', data_type=(u'ID', u'2', u'3'),
                position=4,
                codes=[])
        ),
        Element(
            u'N405', Properties(
                desc=u'Location Qualifier', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=5,
                codes=[u'RJ'])
        ),
        Element(
            u'N406', Properties(
                desc=u'Location Identifier', req_sit=u'S',
                data_type=(u'AN', u'1', u'30'), position=6,
                codes=[])
        ),
        Element(
            u'N407', Properties(
                desc=u'Country Subdivision Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=7,
                codes=[])
        ),
    ),
    Segment(
        u'PER',
        Properties(
            syntax=u'P0304 P0506 P0708', position=u'3800', req_sit=u'S', repeat=u'3',
            desc=u'Subscriber Benefit Related Entity Contact Information'),
        Element(
            u'PER01', Properties(
                desc=u'Contact Function Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=1,
                codes=[u'IC'])
        ),
        Element(
            u'PER02', Properties(
                desc=u'Name', req_sit=u'S', data_type=(u'AN', u'1', u'60'),
                position=2,
                codes=[])
        ),
        Element(
            u'PER03', Properties(
                desc=u'Communication Number Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'ED', u'EM', u'FX', u'TE', u'UR', u'WP'])
        ),
        Element(
            u'PER04', Properties(
                desc=u'Communication Number', req_sit=u'S',
                data_type=(u'AN', u'1', u'256'), position=4,
                codes=[])
        ),
        Element(
            u'PER05', Properties(
                desc=u'Communication Number Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=5,
                codes=[u'ED', u'EM', u'EX', u'FX', u'TE', u'UR', u'WP'])
        ),
        Element(
            u'PER06', Properties(
                desc=u'Communication Number', req_sit=u'S',
                data_type=(u'AN', u'1', u'256'), position=6,
                codes=[])
        ),
        Element(
            u'PER07', Properties(
                desc=u'Communication Number Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=7,
                codes=[u'ED', u'EM', u'EX', u'FX', u'TE', u'UR', u'WP'])
        ),
        Element(
            u'PER08', Properties(
                desc=u'Communication Number', req_sit=u'S',
                data_type=(u'AN', u'1', u'256'), position=8,
                codes=[])
        ),
        Element(
            u'PER09', Properties(
                desc=u'Contact Inquiry Reference', req_sit=u'N',
                data_type=(u'AN', u'1', u'20'), position=9,
                codes=[])
        ),
    ),
    Segment(
        u'PRV', Properties(
            syntax=u'P0203', position=u'3900', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Benefit Related Provider Information'),
        Element(
            u'PRV01',
            Properties(
                desc=u'Provider Code', req_sit=u'R', data_type=(u'ID', u'1', u'3'),
                position=1,
                codes=[u'AD', u'AT', u'BI', u'CO', u'CV', u'H', u'HH', u'LA', u'OT',
                       u'P1', u'P2', u'PC', u'PE', u'R', u'RF', u'SB', u'SK',
                       u'SU'])
        ),
        Element(
            u'PRV02', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=2,
                codes=[u'PXC'])
        ),
        Element(
            u'PRV03', Properties(
                desc=u'Reference Identification', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=3,
                codes=[])
        ),
        Element(
            u'PRV04', Properties(
                desc=u'State or Province Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=4,
                codes=[])
        ),
        Composite(
            u'C035', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'05',
                desc=u'Provider Specialty Information'),
        ),
        Element(
            u'PRV06', Properties(
                desc=u'Provider Organization Code', req_sit=u'N',
                data_type=(u'ID', u'3', u'3'), position=6,
                codes=[])
        ),
    ),
    Segment(
        u'LE', Properties(
            syntax='', position=u'4000', req_sit=u'S', repeat=u'1',
            desc=u'Loop Trailer'),
        Element(
            u'LE01', Properties(
                desc=u'Loop Identifier Code', req_sit=u'R',
                data_type=(u'AN', u'1', u'4'), position=1,
                codes=[u'2120'])
        ),
    ),
)
parsed_271_2115C = Loop(
    u'2115C', Properties(
        position=u'1710', looptype='', repeat=u'10', req_sit=u'S',
        desc=u'Subscriber Eligibility or Benefit Additional Information'),
    Segment(
        u'III', Properties(
            syntax=u'P0102 L030405', position=u'2600', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Eligibility or Benefit Additional Information'),
        Element(
            u'III01', Properties(
                desc=u'Code List Qualifier Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=1,
                codes=[u'GR', u'NI', u'ZZ'])
        ),
        Element(
            u'III02',
            Properties(
                desc=u'Industry Code', req_sit=u'S', data_type=(u'AN', u'1', u'30'),
                position=2,
                codes=[])
        ),
        Element(
            u'III03',
            Properties(
                desc=u'Code Category', req_sit=u'S', data_type=(u'ID', u'2', u'2'),
                position=3,
                codes=[u'44'])
        ),
        Element(
            u'III04', Properties(
                desc=u'Free-form Message Text', req_sit=u'S',
                data_type=(u'AN', u'1', u'264'), position=4,
                codes=[])
        ),
        Element(
            u'III05',
            Properties(
                desc=u'Quantity', req_sit=u'N', data_type=(u'R', u'1', u'15'),
                position=5,
                codes=[])
        ),
        Composite(
            u'C001', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'06',
                desc=u'Composite Unit of Measure'),
        ),
        Element(
            u'III07', Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=7,
                codes=[])
        ),
        Element(
            u'III08', Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=8,
                codes=[])
        ),
        Element(
            u'III09', Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=9,
                codes=[])
        ),
    ),
    Segment(
        u'LS',
        Properties(
            syntax='', position=u'3300', req_sit=u'S', repeat=u'1', desc=u'Loop Header'),
        Element(
            u'LS01', Properties(
                desc=u'Loop Identifier Code', req_sit=u'R',
                data_type=(u'AN', u'1', u'4'), position=1,
                codes=[u'2120'])
        ),
    ),
    parsed_271_2120C,
)
parsed_271_2110C = Loop(
    u'2110C', Properties(
        position=u'1300', looptype='', repeat=u'>1', req_sit=u'S',
        desc=u'Subscriber Eligibility or Benefit Information'),
    Segment(
        u'EB', Properties(
            syntax=u'P0910', position=u'1300', req_sit=u'R', repeat=u'1',
            desc=u'Subscriber Eligibility or Benefit Information'),
        Element(
            u'EB01',
            Properties(
                desc=u'Eligibility or Benefit Information Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'2'), position=1,
                codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'A', u'B',
                       u'C', u'CB', u'D', u'E', u'F', u'G', u'H', u'I', u'J', u'K',
                       u'L', u'M', u'MC', u'N', u'O', u'P', u'Q', u'R', u'S', u'T',
                       u'U', u'V', u'W', u'X', u'Y'])
        ),
        Element(
            u'EB02', Properties(
                desc=u'Coverage Level Code', req_sit=u'S',
                data_type=(u'ID', u'3', u'3'), position=2,
                codes=[u'CHD', u'DEP', u'ECH', u'EMP', u'ESP', u'FAM',
                       u'IND', u'SPC', u'SPO'])
        ),
        Element(
            u'EB03', Properties(
                desc=u'Service Type Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=3,
                codes=[u'1', u'10', u'11', u'12', u'13', u'14', u'15',
                       u'16', u'17', u'18', u'19', u'2', u'20', u'21',
                       u'22', u'23', u'24', u'25', u'26', u'27', u'28',
                       u'3', u'30', u'32', u'33', u'34', u'35', u'36',
                       u'37', u'38', u'39', u'4', u'40', u'41', u'42',
                       u'43', u'44', u'45', u'46', u'47', u'48', u'49',
                       u'5', u'50', u'51', u'52', u'53', u'54', u'55',
                       u'56', u'57', u'58', u'59', u'6', u'60', u'61',
                       u'62', u'63', u'64', u'65', u'66', u'67', u'68',
                       u'69', u'7', u'70', u'71', u'72', u'73', u'74',
                       u'75', u'76', u'77', u'78', u'79', u'8', u'80',
                       u'81', u'82', u'83', u'84', u'85', u'86', u'87',
                       u'88', u'89', u'9', u'90', u'91', u'92', u'93',
                       u'94', u'95', u'96', u'97', u'98', u'99', u'A0',
                       u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7',
                       u'A8', u'A9', u'AA', u'AB', u'AC', u'AD', u'AE',
                       u'AF', u'AG', u'AH', u'AI', u'AJ', u'AK', u'AL',
                       u'AM', u'AN', u'AO', u'AQ', u'AR', u'B1', u'B2',
                       u'B3', u'BA', u'BB', u'BC', u'BD', u'BE', u'BF',
                       u'BG', u'BH', u'BI', u'BJ', u'BK', u'BL', u'BM',
                       u'BN', u'BP', u'BQ', u'BR', u'BS', u'BT', u'BU',
                       u'BV', u'BW', u'BX', u'BY', u'BZ', u'C1', u'CA',
                       u'CB', u'CC', u'CD', u'CE', u'CF', u'CG', u'CH',
                       u'CI', u'CJ', u'CK', u'CL', u'CM', u'CN', u'CO',
                       u'CP', u'CQ', u'DG', u'DM', u'DS', u'GF', u'GN',
                       u'GY', u'IC', u'MH', u'NI', u'ON', u'PT', u'PU',
                       u'RN', u'RT', u'TC', u'TN', u'UC'])
        ),
        Element(
            u'EB04', Properties(
                desc=u'Insurance Type Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=4,
                codes=[u'12', u'13', u'14', u'15', u'16', u'41', u'42',
                       u'43', u'47', u'AP', u'C1', u'CO', u'CP', u'D',
                       u'DB', u'EP', u'FF', u'GP', u'HM', u'HN', u'HS',
                       u'IN', u'IP', u'LC', u'LD', u'LI', u'LT', u'MA',
                       u'MB', u'MC', u'MH', u'MI', u'MP', u'OT', u'PE',
                       u'PL', u'PP', u'PR', u'PS', u'QM', u'RP', u'SP',
                       u'TF', u'WC', u'WU'])
        ),
        Element(
            u'EB05', Properties(
                desc=u'Plan Coverage Description', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=5,
                codes=[])
        ),
        Element(
            u'EB06', Properties(
                desc=u'Time Period Qualifier', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=6,
                codes=[u'13', u'21', u'22', u'23', u'24', u'25', u'26',
                       u'27', u'28', u'29', u'30', u'31', u'32', u'33',
                       u'34', u'35', u'36', u'6', u'7'])
        ),
        Element(
            u'EB07',
            Properties(
                desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R', u'1', u'18'),
                position=7,
                codes=[])
        ),
        Element(
            u'EB08', Properties(
                desc=u'Percentage as Decimal', req_sit=u'S',
                data_type=(u'R', u'1', u'10'), position=8,
                codes=[])
        ),
        Element(
            u'EB09', Properties(
                desc=u'Quantity Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=9,
                codes=[u'8H', u'99', u'CA', u'CE', u'D3', u'DB', u'DY',
                       u'HS', u'LA', u'LE', u'M2', u'MN', u'P6', u'QA',
                       u'S7', u'S8', u'VS', u'YY'])
        ),
        Element(
            u'EB10',
            Properties(
                desc=u'Quantity', req_sit=u'S', data_type=(u'R', u'1', u'15'),
                position=10,
                codes=[])
        ),
        Element(
            u'EB11', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'1'), position=11,
                codes=[u'N', u'U', u'Y'])
        ),
        Element(
            u'EB12', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'1'), position=12,
                codes=[u'N', u'U', u'W', u'Y'])
        ),
        Composite(
            u'C003', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'13',
                desc=u'Composite Medical Procedure Identifier'),
            Element(
                u'EB13-01',
                Properties(
                    desc=u'Product/Service ID Qualifier', req_sit=u'R',
                    data_type=(u'ID', u'2', u'2'), position=0,
                    codes=[u'AD', u'CJ', u'HC', u'ID', u'IV', u'N4', u'ZZ'])
            ),
            Element(
                u'EB13-02', Properties(
                    desc=u'Product/Service ID', req_sit=u'R',
                    data_type=(u'AN', u'1', u'48'), position=1,
                    codes=[])
            ),
            Element(
                u'EB13-03', Properties(
                    desc=u'Procedure Modifier', req_sit=u'S',
                    data_type=(u'AN', u'2', u'2'), position=2,
                    codes=[])
            ),
            Element(
                u'EB13-04', Properties(
                    desc=u'Procedure Modifier', req_sit=u'S',
                    data_type=(u'AN', u'2', u'2'), position=3,
                    codes=[])
            ),
            Element(
                u'EB13-05', Properties(
                    desc=u'Procedure Modifier', req_sit=u'S',
                    data_type=(u'AN', u'2', u'2'), position=4,
                    codes=[])
            ),
            Element(
                u'EB13-06', Properties(
                    desc=u'Procedure Modifier', req_sit=u'S',
                    data_type=(u'AN', u'2', u'2'), position=5,
                    codes=[])
            ),
            Element(
                u'EB13-07', Properties(
                    desc=u'Description', req_sit=u'N',
                    data_type=(u'AN', u'1', u'80'), position=6,
                    codes=[])
            ),
            Element(
                u'EB13-08', Properties(
                    desc=u'Product/Service ID', req_sit=u'S',
                    data_type=(u'AN', u'1', u'48'), position=7,
                    codes=[])
            ),
        ),
        Composite(
            u'C004', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'14',
                desc=u'Composite Diagnosis Code Pointer'),
            Element(
                u'EB14-01', Properties(
                    desc=u'Diagnosis Code Pointer', req_sit=u'R',
                    data_type=(u'N0', u'1', u'2'), position=0,
                    codes=[])
            ),
            Element(
                u'EB14-02', Properties(
                    desc=u'Diagnosis Code Pointer', req_sit=u'S',
                    data_type=(u'N0', u'1', u'2'), position=1,
                    codes=[])
            ),
            Element(
                u'EB14-03', Properties(
                    desc=u'Diagnosis Code Pointer', req_sit=u'S',
                    data_type=(u'N0', u'1', u'2'), position=2,
                    codes=[])
            ),
            Element(
                u'EB14-04', Properties(
                    desc=u'Diagnosis Code Pointer', req_sit=u'S',
                    data_type=(u'N0', u'1', u'2'), position=3,
                    codes=[])
            ),
        ),
    ),
    Segment(
        u'HSD', Properties(
            syntax=u'P0102 C0605', position=u'1350', req_sit=u'S', repeat=u'9',
            desc=u'Health Care Services Delivery'),
        Element(
            u'HSD01', Properties(
                desc=u'Quantity Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=1,
                codes=[u'DY', u'FL', u'HS', u'MN', u'VS'])
        ),
        Element(
            u'HSD02',
            Properties(
                desc=u'Quantity', req_sit=u'S', data_type=(u'R', u'1', u'15'),
                position=2,
                codes=[])
        ),
        Element(
            u'HSD03', Properties(
                desc=u'Unit or Basis for Measurement Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'DA', u'MO', u'VS', u'WK', u'YR'])
        ),
        Element(
            u'HSD04', Properties(
                desc=u'Sample Selection Modulus', req_sit=u'S',
                data_type=(u'R', u'1', u'6'), position=4,
                codes=[])
        ),
        Element(
            u'HSD05', Properties(
                desc=u'Time Period Qualifier', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=5,
                codes=[u'21', u'22', u'23', u'24', u'25', u'26', u'27',
                       u'28', u'29', u'30', u'31', u'32', u'33', u'34',
                       u'35', u'6', u'7'])
        ),
        Element(
            u'HSD06', Properties(
                desc=u'Number of Periods', req_sit=u'S',
                data_type=(u'N0', u'1', u'3'), position=6,
                codes=[])
        ),
        Element(
            u'HSD07',
            Properties(
                desc=u'Ship/Delivery or Calendar Pattern Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=7,
                codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'A',
                       u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'J', u'K', u'L',
                       u'M', u'N', u'O', u'P', u'Q', u'R', u'S', u'SG', u'SL', u'SP',
                       u'SX', u'SY', u'SZ', u'T', u'U', u'V', u'W', u'X', u'Y'])
        ),
        Element(
            u'HSD08', Properties(
                desc=u'Ship/Delivery Pattern Time Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'1'), position=8,
                codes=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'Y'])
        ),
    ),
    Segment(
        u'REF', Properties(
            syntax=u'R0203', position=u'1400', req_sit=u'S', repeat=u'9',
            desc=u'Subscriber Additional Identification'),
        Element(
            u'REF01', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'18', u'1L', u'1W', u'49', u'6P', u'9F', u'ALS',
                       u'CLI', u'F6', u'FO', u'G1', u'IG', u'M7', u'N6',
                       u'NQ'])
        ),
        Element(
            u'REF02', Properties(
                desc=u'Reference Identification', req_sit=u'R',
                data_type=(u'AN', u'1', u'50'), position=2,
                codes=[])
        ),
        Element(
            u'REF03',
            Properties(
                desc=u'Description', req_sit=u'S', data_type=(u'AN', u'1', u'80'),
                position=3,
                codes=[])
        ),
        Composite(
            u'C040', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'04',
                desc=u'Reference Identifier'),
        ),
    ),
    Segment(
        u'DTP', Properties(
            syntax='', position=u'1500', req_sit=u'S', repeat=u'20',
            desc=u'Subscriber Eligibility/Benefit Date'),
        Element(
            u'DTP01', Properties(
                desc=u'Date/Time Qualifier', req_sit=u'R',
                data_type=(u'ID', u'3', u'3'), position=1,
                codes=[u'096', u'193', u'194', u'198', u'290', u'291',
                       u'292', u'295', u'304', u'307', u'318', u'346',
                       u'348', u'349', u'356', u'357', u'435', u'472',
                       u'636', u'771'])
        ),
        Element(
            u'DTP02', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=2,
                codes=[u'D8', u'RD8'])
        ),
        Element(
            u'DTP03', Properties(
                desc=u'Date Time Period', req_sit=u'R',
                data_type=(u'AN', u'1', u'35'), position=3,
                codes=[])
        ),
    ),
    Segment(
        u'AAA', Properties(
            syntax='', position=u'1600', req_sit=u'S', repeat=u'9',
            desc=u'Subscriber Request Validation'),
        Element(
            u'AAA01', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'N', u'Y'])
        ),
        Element(
            u'AAA02', Properties(
                desc=u'Agency Qualifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'AAA03', Properties(
                desc=u'Reject Reason Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'15', u'33', u'52', u'53', u'54', u'55', u'56',
                       u'57', u'60', u'61', u'62', u'63', u'69', u'70',
                       u'98', u'AA', u'AE', u'AF', u'AG', u'AO', u'CI',
                       u'E8', u'IA', u'MA'])
        ),
        Element(
            u'AAA04', Properties(
                desc=u'Follow-up Action Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'C', u'N', u'R', u'W', u'X', u'Y'])
        ),
    ),
    parsed_271_2115C,
    Segment(
        u'MSG', Properties(
            syntax=u'C0302', position=u'2500', req_sit=u'S', repeat=u'10',
            desc=u'Message Text'),
        Element(
            u'MSG01', Properties(
                desc=u'Free-form Message Text', req_sit=u'R',
                data_type=(u'AN', u'1', u'264'), position=1,
                codes=[])
        ),
        Element(
            u'MSG02', Properties(
                desc=u'Printer Carriage Control Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'MSG03',
            Properties(
                desc=u'Number', req_sit=u'N', data_type=(u'N0', u'1', u'9'),
                position=3,
                codes=[])
        ),
    ),
    Segment(
        u'III', Properties(
            syntax=u'P0102 L030405', position=u'2600', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Eligibility or Benefit Additional Information'),
        Element(
            u'III01', Properties(
                desc=u'Code List Qualifier Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=1,
                codes=[u'GR', u'NI', u'ZZ'])
        ),
        Element(
            u'III02',
            Properties(
                desc=u'Industry Code', req_sit=u'S', data_type=(u'AN', u'1', u'30'),
                position=2,
                codes=[])
        ),
        Element(
            u'III03',
            Properties(
                desc=u'Code Category', req_sit=u'S', data_type=(u'ID', u'2', u'2'),
                position=3,
                codes=[u'44'])
        ),
        Element(
            u'III04', Properties(
                desc=u'Free-form Message Text', req_sit=u'S',
                data_type=(u'AN', u'1', u'264'), position=4,
                codes=[])
        ),
        Element(
            u'III05',
            Properties(
                desc=u'Quantity', req_sit=u'N', data_type=(u'R', u'1', u'15'),
                position=5,
                codes=[])
        ),
        Composite(
            u'C001', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'06',
                desc=u'Composite Unit of Measure'),
        ),
        Element(
            u'III07', Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=7,
                codes=[])
        ),
        Element(
            u'III08', Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=8,
                codes=[])
        ),
        Element(
            u'III09', Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=9,
                codes=[])
        ),
    ),
)
parsed_271_2100C = Loop(
    u'2100C',
    Properties(
        position=u'0300', looptype='', repeat=u'1', req_sit=u'R', desc=u'Subscriber Name'),
    Segment(
        u'NM1',
        Properties(
            syntax=u'P0809 C1110 C1203', position=u'0300', req_sit=u'R', repeat=u'1',
            desc=u'Subscriber Name'),
        Element(
            u'NM101', Properties(
                desc=u'Entity Identifier Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'IL'])
        ),
        Element(
            u'NM102', Properties(
                desc=u'Entity Type Qualifier', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=2,
                codes=[u'1', u'2'])
        ),
        Element(
            u'NM103', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'S',
                data_type=(u'AN', u'1', u'60'), position=3,
                codes=[])
        ),
        Element(
            u'NM104',
            Properties(
                desc=u'Name First', req_sit=u'S', data_type=(u'AN', u'1', u'35'),
                position=4,
                codes=[])
        ),
        Element(
            u'NM105',
            Properties(
                desc=u'Name Middle', req_sit=u'S', data_type=(u'AN', u'1', u'25'),
                position=5,
                codes=[])
        ),
        Element(
            u'NM106',
            Properties(
                desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN', u'1', u'10'),
                position=6,
                codes=[])
        ),
        Element(
            u'NM107',
            Properties(
                desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN', u'1', u'10'),
                position=7,
                codes=[])
        ),
        Element(
            u'NM108', Properties(
                desc=u'Identification Code Qualifier', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=8,
                codes=[u'II', u'MI'])
        ),
        Element(
            u'NM109', Properties(
                desc=u'Identification Code', req_sit=u'S',
                data_type=(u'AN', u'2', u'80'), position=9,
                codes=[])
        ),
        Element(
            u'NM110', Properties(
                desc=u'Entity Relationship Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=10,
                codes=[])
        ),
        Element(
            u'NM111', Properties(
                desc=u'Entity Identifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'3'), position=11,
                codes=[])
        ),
        Element(
            u'NM112', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'N',
                data_type=(u'AN', u'1', u'60'), position=12,
                codes=[])
        ),
    ),
    Segment(
        u'REF', Properties(
            syntax=u'R0203', position=u'0400', req_sit=u'S', repeat=u'9',
            desc=u'Subscriber Additional Identification'),
        Element(
            u'REF01', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'18', u'1L', u'1W', u'3H', u'49', u'6P', u'CE',
                       u'CT', u'EA', u'EJ', u'F6', u'GH', u'HJ', u'IF',
                       u'IG', u'N6', u'NQ', u'Q4', u'SY', u'Y4'])
        ),
        Element(
            u'REF02', Properties(
                desc=u'Reference Identification', req_sit=u'R',
                data_type=(u'AN', u'1', u'50'), position=2,
                codes=[])
        ),
        Element(
            u'REF03',
            Properties(
                desc=u'Description', req_sit=u'S', data_type=(u'AN', u'1', u'80'),
                position=3,
                codes=[])
        ),
        Composite(
            u'C040', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'04',
                desc=u'Reference Identifier'),
        ),
    ),
    Segment(
        u'N3', Properties(
            syntax='', position=u'0600', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Address'),
        Element(
            u'N301', Properties(
                desc=u'Address Information', req_sit=u'R',
                data_type=(u'AN', u'1', u'55'), position=1,
                codes=[])
        ),
        Element(
            u'N302', Properties(
                desc=u'Address Information', req_sit=u'S',
                data_type=(u'AN', u'1', u'55'), position=2,
                codes=[])
        ),
    ),
    Segment(
        u'N4',
        Properties(
            syntax=u'E0207 C0605 C0704', position=u'0700', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber City, State, ZIP Code'),
        Element(
            u'N401',
            Properties(
                desc=u'City Name', req_sit=u'R', data_type=(u'AN', u'2', u'30'),
                position=1,
                codes=[])
        ),
        Element(
            u'N402', Properties(
                desc=u'State or Province Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'N403',
            Properties(
                desc=u'Postal Code', req_sit=u'S', data_type=(u'ID', u'3', u'15'),
                position=3,
                codes=[])
        ),
        Element(
            u'N404',
            Properties(
                desc=u'Country Code', req_sit=u'S', data_type=(u'ID', u'2', u'3'),
                position=4,
                codes=[])
        ),
        Element(
            u'N405', Properties(
                desc=u'Location Qualifier', req_sit=u'N',
                data_type=(u'ID', u'1', u'2'), position=5,
                codes=[])
        ),
        Element(
            u'N406', Properties(
                desc=u'Location Identifier', req_sit=u'N',
                data_type=(u'AN', u'1', u'30'), position=6,
                codes=[])
        ),
        Element(
            u'N407', Properties(
                desc=u'Country Subdivision Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=7,
                codes=[])
        ),
    ),
    Segment(
        u'AAA', Properties(
            syntax='', position=u'0850', req_sit=u'S', repeat=u'9',
            desc=u'Subscriber Request Validation'),
        Element(
            u'AAA01', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'N', u'Y'])
        ),
        Element(
            u'AAA02', Properties(
                desc=u'Agency Qualifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'AAA03', Properties(
                desc=u'Reject Reason Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'15', u'35', u'42', u'43', u'45', u'47', u'48',
                       u'49', u'51', u'52', u'56', u'57', u'58', u'60',
                       u'61', u'62', u'63', u'71', u'72', u'73', u'74',
                       u'75', u'76', u'78'])
        ),
        Element(
            u'AAA04', Properties(
                desc=u'Follow-up Action Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'C', u'N', u'R', u'S', u'W', u'X', u'Y'])
        ),
    ),
    Segment(
        u'PRV', Properties(
            syntax=u'P0203', position=u'0900', req_sit=u'S', repeat=u'1',
            desc=u'Provider Information'),
        Element(
            u'PRV01',
            Properties(
                desc=u'Provider Code', req_sit=u'R', data_type=(u'ID', u'1', u'3'),
                position=1,
                codes=[u'AD', u'AT', u'BI', u'CO', u'CV', u'H', u'HH', u'LA', u'OT',
                       u'P1', u'P2', u'PC', u'PE', u'R', u'RF', u'SK', u'SU'])
        ),
        Element(
            u'PRV02', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=2,
                codes=[u'PXC'])
        ),
        Element(
            u'PRV03', Properties(
                desc=u'Reference Identification', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=3,
                codes=[])
        ),
        Element(
            u'PRV04', Properties(
                desc=u'State or Province Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=4,
                codes=[])
        ),
        Composite(
            u'C035', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'05',
                desc=u'Provider Specialty Information'),
        ),
        Element(
            u'PRV06', Properties(
                desc=u'Provider Organization Code', req_sit=u'N',
                data_type=(u'ID', u'3', u'3'), position=6,
                codes=[])
        ),
    ),
    Segment(
        u'DMG',
        Properties(
            syntax=u'P0102 P1011 C1105', position=u'1000', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Demographic Information'),
        Element(
            u'DMG01', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'D8'])
        ),
        Element(
            u'DMG02', Properties(
                desc=u'Date Time Period', req_sit=u'S',
                data_type=(u'AN', u'1', u'35'), position=2,
                codes=[])
        ),
        Element(
            u'DMG03',
            Properties(
                desc=u'Gender Code', req_sit=u'S', data_type=(u'ID', u'1', u'1'),
                position=3,
                codes=[u'F', u'M', u'U'])
        ),
        Element(
            u'DMG04', Properties(
                desc=u'Marital Status Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[])
        ),
        Composite(
            u'C056', Properties(
                req_sit=u'N', repeat=u'10', refdes='', seq=u'05',
                desc=u'Composite Race or Ethnicity Information'),
        ),
        Element(
            u'DMG06', Properties(
                desc=u'Citizenship Status Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'2'), position=6,
                codes=[])
        ),
        Element(
            u'DMG07',
            Properties(
                desc=u'Country Code', req_sit=u'N', data_type=(u'ID', u'2', u'3'),
                position=7,
                codes=[])
        ),
        Element(
            u'DMG08', Properties(
                desc=u'Basis of Verification Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'2'), position=8,
                codes=[])
        ),
        Element(
            u'DMG09',
            Properties(
                desc=u'Quantity', req_sit=u'N', data_type=(u'R', u'1', u'15'),
                position=9,
                codes=[])
        ),
        Element(
            u'DMG10', Properties(
                desc=u'Code List Qualifier Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'3'), position=10,
                codes=[])
        ),
        Element(
            u'DMG11',
            Properties(
                desc=u'Industry Code', req_sit=u'N', data_type=(u'AN', u'1', u'30'),
                position=11,
                codes=[])
        ),
    ),
    Segment(
        u'INS', Properties(
            syntax=u'P1112', position=u'1100', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Relationship'),
        Element(
            u'INS01', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'Y'])
        ),
        Element(
            u'INS02', Properties(
                desc=u'Individual Relationship Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[u'18'])
        ),
        Element(
            u'INS03', Properties(
                desc=u'Maintenance Type Code', req_sit=u'S',
                data_type=(u'ID', u'3', u'3'), position=3,
                codes=[u'001'])
        ),
        Element(
            u'INS04', Properties(
                desc=u'Maintenance Reason Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=4,
                codes=[u'25'])
        ),
        Element(
            u'INS05', Properties(
                desc=u'Benefit Status Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=5,
                codes=[])
        ),
        Composite(
            u'C052', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'06',
                desc=u'Medicare Status Code'),
        ),
        Element(
            u'INS07', Properties(
                desc=u'Consolidated Omnibus Budget Reconciliation Act (COBRA) Qualifying',
                req_sit=u'N', data_type=(u'ID', u'1', u'2'), position=7,
                codes=[])
        ),
        Element(
            u'INS08', Properties(
                desc=u'Employment Status Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=8,
                codes=[])
        ),
        Element(
            u'INS09', Properties(
                desc=u'Student Status Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=9,
                codes=[])
        ),
        Element(
            u'INS10', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=10,
                codes=[])
        ),
        Element(
            u'INS11', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                data_type=(u'ID', u'2', u'3'), position=11,
                codes=[])
        ),
        Element(
            u'INS12', Properties(
                desc=u'Date Time Period', req_sit=u'N',
                data_type=(u'AN', u'1', u'35'), position=12,
                codes=[])
        ),
        Element(
            u'INS13', Properties(
                desc=u'Confidentiality Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=13,
                codes=[])
        ),
        Element(
            u'INS14',
            Properties(
                desc=u'City Name', req_sit=u'N', data_type=(u'AN', u'2', u'30'),
                position=14,
                codes=[])
        ),
        Element(
            u'INS15', Properties(
                desc=u'State or Province Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=15,
                codes=[])
        ),
        Element(
            u'INS16',
            Properties(
                desc=u'Country Code', req_sit=u'N', data_type=(u'ID', u'2', u'3'),
                position=16,
                codes=[])
        ),
        Element(
            u'INS17',
            Properties(
                desc=u'Number', req_sit=u'S', data_type=(u'N0', u'1', u'9'),
                position=17,
                codes=[])
        ),
    ),
    Segment(
        u'HI', Properties(
            syntax='', position=u'1150', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Health Care Diagnosis Code'),
        Composite(
            u'C022', Properties(
                req_sit=u'R', repeat='', refdes='', seq=u'01',
                desc=u'Health Care Code Information'),
            Element(
                u'HI01-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABK', u'BK'])
            ),
            Element(
                u'HI01-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI01-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI01-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI01-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI01-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI01-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI01-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI01-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'02',
                desc=u'Health Care Code Information'),
            Element(
                u'HI02-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI02-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI02-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI02-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI02-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI02-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI02-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI02-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI02-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'03',
                desc=u'Health Care Code Information'),
            Element(
                u'HI03-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI03-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI03-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI03-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI03-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI03-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI03-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI03-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI03-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'04',
                desc=u'Health Care Code Information'),
            Element(
                u'HI04-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI04-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI04-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI04-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI04-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI04-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI04-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI04-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI04-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'05',
                desc=u'Health Care Code Information'),
            Element(
                u'HI05-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI05-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI05-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI05-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI05-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI05-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI05-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI05-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI05-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'06',
                desc=u'Health Care Code Information'),
            Element(
                u'HI06-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI06-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI06-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI06-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI06-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI06-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI06-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI06-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI06-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'07',
                desc=u'Health Care Code Information'),
            Element(
                u'HI07-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI07-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI07-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI07-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI07-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI07-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI07-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI07-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI07-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'08',
                desc=u'Health Care Code Information'),
            Element(
                u'HI08-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI08-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI08-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI08-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI08-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI08-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI08-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI08-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI08-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'09',
                desc=u'Health Care Code Information'),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'10',
                desc=u'Health Care Code Information'),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'11',
                desc=u'Health Care Code Information'),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'12',
                desc=u'Health Care Code Information'),
        ),
    ),
    Segment(
        u'DTP', Properties(
            syntax='', position=u'1200', req_sit=u'S', repeat=u'9',
            desc=u'Subscriber Date'),
        Element(
            u'DTP01', Properties(
                desc=u'Date/Time Qualifier', req_sit=u'R',
                data_type=(u'ID', u'3', u'3'), position=1,
                codes=[u'096', u'102', u'152', u'291', u'307', u'318',
                       u'340', u'341', u'342', u'343', u'346', u'347',
                       u'356', u'357', u'382', u'435', u'442', u'458',
                       u'472', u'539', u'540', u'636', u'771'])
        ),
        Element(
            u'DTP02', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=2,
                codes=[u'D8', u'RD8'])
        ),
        Element(
            u'DTP03', Properties(
                desc=u'Date Time Period', req_sit=u'R',
                data_type=(u'AN', u'1', u'35'), position=3,
                codes=[])
        ),
    ),
    Segment(
        u'MPI', Properties(
            syntax=u'P0607', position=u'1275', req_sit=u'S', repeat=u'1',
            desc=u'Subscriber Military Personnel Information'),
        Element(
            u'MPI01', Properties(
                desc=u'Information Status Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'A', u'C', u'L', u'O', u'P', u'S', u'T'])
        ),
        Element(
            u'MPI02', Properties(
                desc=u'Employment Status Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[u'AE', u'AO', u'AS', u'AT', u'AU', u'CC', u'DD',
                       u'HD', u'IR', u'LX', u'PE', u'RE', u'RM', u'RR',
                       u'RU'])
        ),
        Element(
            u'MPI03', Properties(
                desc=u'Government Service Affiliation Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=3,
                codes=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H',
                       u'I', u'J', u'K', u'L', u'M', u'N', u'O', u'Q',
                       u'R', u'S', u'U', u'W'])
        ),
        Element(
            u'MPI04',
            Properties(
                desc=u'Description', req_sit=u'S', data_type=(u'AN', u'1', u'80'),
                position=4,
                codes=[])
        ),
        Element(
            u'MPI05', Properties(
                desc=u'Military Service Rank Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=5,
                codes=[u'A1', u'A2', u'A3', u'B1', u'B2', u'C1', u'C2',
                       u'C3', u'C4', u'C5', u'C6', u'C7', u'C8', u'C9',
                       u'E1', u'F1', u'F2', u'F3', u'F4', u'G1', u'G4',
                       u'L1', u'L2', u'L3', u'L4', u'L5', u'L6', u'M1',
                       u'M2', u'M3', u'M4', u'M5', u'M6', u'P1', u'P2',
                       u'P3', u'P4', u'P5', u'R1', u'R2', u'S1', u'S2',
                       u'S3', u'S4', u'S5', u'S6', u'S7', u'S8', u'S9',
                       u'SA', u'SB', u'SC', u'T1', u'V1', u'W1'])
        ),
        Element(
            u'MPI06', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=6,
                codes=[u'D8', u'RD8'])
        ),
        Element(
            u'MPI07', Properties(
                desc=u'Date Time Period', req_sit=u'S',
                data_type=(u'AN', u'1', u'35'), position=7,
                codes=[])
        ),
    ),
    parsed_271_2110C,
)
parsed_271_2000C = Loop(
    u'2000C',
    Properties(
        position=u'0140', looptype='', repeat=u'>1', req_sit=u'S', desc=u'Subscriber Level'),
    Segment(
        u'HL', Properties(
            syntax='', position=u'0100', req_sit=u'R', repeat=u'1',
            desc=u'Subscriber Level'),
        Element(
            u'HL01', Properties(
                desc=u'Hierarchical ID Number', req_sit=u'R',
                data_type=(u'AN', u'1', u'12'), position=1,
                codes=[])
        ),
        Element(
            u'HL02', Properties(
                desc=u'Hierarchical Parent ID Number', req_sit=u'R',
                data_type=(u'AN', u'1', u'12'), position=2,
                codes=[])
        ),
        Element(
            u'HL03', Properties(
                desc=u'Hierarchical Level Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'2'), position=3,
                codes=[u'22'])
        ),
        Element(
            u'HL04', Properties(
                desc=u'Hierarchical Child Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'0', u'1'])
        ),
    ),
    Segment(
        u'TRN', Properties(
            syntax='', position=u'0200', req_sit=u'S', repeat=u'3',
            desc=u'Subscriber Trace Number'),
        Element(
            u'TRN01',
            Properties(
                desc=u'Trace Type Code', req_sit=u'R', data_type=(u'ID', u'1', u'2'),
                position=1,
                codes=[u'1', u'2'])
        ),
        Element(
            u'TRN02', Properties(
                desc=u'Reference Identification', req_sit=u'R',
                data_type=(u'AN', u'1', u'50'), position=2,
                codes=[])
        ),
        Element(
            u'TRN03', Properties(
                desc=u'Originating Company Identifier', req_sit=u'R',
                data_type=(u'AN', u'10', u'10'), position=3,
                codes=[])
        ),
        Element(
            u'TRN04', Properties(
                desc=u'Reference Identification', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=4,
                codes=[])
        ),
    ),
    parsed_271_2100C,
)
parsed_271_2120D = Loop(
    u'2120D', Properties(
        position=u'1800', looptype='', repeat=u'23', req_sit=u'S',
        desc=u'Dependent Benefit Related Entity Name'),
    Segment(
        u'NM1',
        Properties(
            syntax=u'P0809 C1110 C1203', position=u'3400', req_sit=u'R', repeat=u'1',
            desc=u'Dependent Benefit Related Entity Name'),
        Element(
            u'NM101', Properties(
                desc=u'Entity Identifier Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'13', u'1I', u'1P', u'2B', u'36', u'73', u'FA',
                       u'GP', u'GW', u'I3', u'IL', u'LR', u'OC', u'P3',
                       u'P4', u'P5', u'PR', u'PRP', u'SEP', u'TTP', u'VER',
                       u'VN', u'VY', u'X3', u'Y2'])
        ),
        Element(
            u'NM102', Properties(
                desc=u'Entity Type Qualifier', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=2,
                codes=[u'1', u'2'])
        ),
        Element(
            u'NM103', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'S',
                data_type=(u'AN', u'1', u'60'), position=3,
                codes=[])
        ),
        Element(
            u'NM104',
            Properties(
                desc=u'Name First', req_sit=u'S', data_type=(u'AN', u'1', u'35'),
                position=4,
                codes=[])
        ),
        Element(
            u'NM105',
            Properties(
                desc=u'Name Middle', req_sit=u'S', data_type=(u'AN', u'1', u'25'),
                position=5,
                codes=[])
        ),
        Element(
            u'NM106',
            Properties(
                desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN', u'1', u'10'),
                position=6,
                codes=[])
        ),
        Element(
            u'NM107',
            Properties(
                desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN', u'1', u'10'),
                position=7,
                codes=[])
        ),
        Element(
            u'NM108', Properties(
                desc=u'Identification Code Qualifier', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=8,
                codes=[u'24', u'34', u'46', u'FA', u'FI', u'II', u'MI',
                       u'NI', u'PI', u'PP', u'SV', u'XV', u'XX'])
        ),
        Element(
            u'NM109', Properties(
                desc=u'Identification Code', req_sit=u'S',
                data_type=(u'AN', u'2', u'80'), position=9,
                codes=[])
        ),
        Element(
            u'NM110', Properties(
                desc=u'Entity Relationship Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=10,
                codes=[u'01', u'02', u'27', u'41', u'48', u'65', u'72'])
        ),
        Element(
            u'NM111', Properties(
                desc=u'Entity Identifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'3'), position=11,
                codes=[])
        ),
        Element(
            u'NM112', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'N',
                data_type=(u'AN', u'1', u'60'), position=12,
                codes=[])
        ),
    ),
    Segment(
        u'N3', Properties(
            syntax='', position=u'3600', req_sit=u'S', repeat=u'1',
            desc=u'Dependent Benefit Related Entity Address'),
        Element(
            u'N301', Properties(
                desc=u'Address Information', req_sit=u'R',
                data_type=(u'AN', u'1', u'55'), position=1,
                codes=[])
        ),
        Element(
            u'N302', Properties(
                desc=u'Address Information', req_sit=u'S',
                data_type=(u'AN', u'1', u'55'), position=2,
                codes=[])
        ),
    ),
    Segment(
        u'N4',
        Properties(
            syntax=u'E0207 C0605 C0704', position=u'3700', req_sit=u'S', repeat=u'1',
            desc=u'Dependent Benefit Related Entity City, State, ZIP Code'),
        Element(
            u'N401',
            Properties(
                desc=u'City Name', req_sit=u'R', data_type=(u'AN', u'2', u'30'),
                position=1,
                codes=[])
        ),
        Element(
            u'N402', Properties(
                desc=u'State or Province Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'N403',
            Properties(
                desc=u'Postal Code', req_sit=u'S', data_type=(u'ID', u'3', u'15'),
                position=3,
                codes=[])
        ),
        Element(
            u'N404',
            Properties(
                desc=u'Country Code', req_sit=u'S', data_type=(u'ID', u'2', u'3'),
                position=4,
                codes=[])
        ),
        Element(
            u'N405', Properties(
                desc=u'Location Qualifier', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=5,
                codes=[u'RJ'])
        ),
        Element(
            u'N406', Properties(
                desc=u'Location Identifier', req_sit=u'S',
                data_type=(u'AN', u'1', u'30'), position=6,
                codes=[])
        ),
        Element(
            u'N407', Properties(
                desc=u'Country Subdivision Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=7,
                codes=[])
        ),
    ),
    Segment(
        u'PER',
        Properties(
            syntax=u'P0304 P0506 P0708', position=u'3800', req_sit=u'S', repeat=u'3',
            desc=u'Dependent Benefit Related Entity Contact Information'),
        Element(
            u'PER01', Properties(
                desc=u'Contact Function Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=1,
                codes=[u'IC'])
        ),
        Element(
            u'PER02', Properties(
                desc=u'Name', req_sit=u'S', data_type=(u'AN', u'1', u'60'),
                position=2,
                codes=[])
        ),
        Element(
            u'PER03', Properties(
                desc=u'Communication Number Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'ED', u'EM', u'FX', u'TE', u'UR', u'WP'])
        ),
        Element(
            u'PER04', Properties(
                desc=u'Communication Number', req_sit=u'S',
                data_type=(u'AN', u'1', u'256'), position=4,
                codes=[])
        ),
        Element(
            u'PER05', Properties(
                desc=u'Communication Number Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=5,
                codes=[u'ED', u'EM', u'EX', u'FX', u'TE', u'UR', u'WP'])
        ),
        Element(
            u'PER06', Properties(
                desc=u'Communication Number', req_sit=u'S',
                data_type=(u'AN', u'1', u'256'), position=6,
                codes=[])
        ),
        Element(
            u'PER07', Properties(
                desc=u'Communication Number Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=7,
                codes=[u'ED', u'EM', u'EX', u'FX', u'TE', u'UR', u'WP'])
        ),
        Element(
            u'PER08', Properties(
                desc=u'Communication Number', req_sit=u'S',
                data_type=(u'AN', u'1', u'256'), position=8,
                codes=[])
        ),
        Element(
            u'PER09', Properties(
                desc=u'Contact Inquiry Reference', req_sit=u'N',
                data_type=(u'AN', u'1', u'20'), position=9,
                codes=[])
        ),
    ),
    Segment(
        u'PRV', Properties(
            syntax=u'P0203', position=u'3900', req_sit=u'S', repeat=u'1',
            desc=u'Dependent Benefit Related Provider Information'),
        Element(
            u'PRV01',
            Properties(
                desc=u'Provider Code', req_sit=u'R', data_type=(u'ID', u'1', u'3'),
                position=1,
                codes=[u'AD', u'AT', u'BI', u'CO', u'CV', u'H', u'HH', u'LA', u'OT',
                       u'P1', u'P2', u'PC', u'PE', u'R', u'RF', u'SB', u'SK',
                       u'SU'])
        ),
        Element(
            u'PRV02', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=2,
                codes=[u'PXC'])
        ),
        Element(
            u'PRV03', Properties(
                desc=u'Reference Identification', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=3,
                codes=[])
        ),
        Element(
            u'PRV04', Properties(
                desc=u'State or Province Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=4,
                codes=[])
        ),
        Composite(
            u'C035', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'05',
                desc=u'Provider Specialty Information'),
        ),
        Element(
            u'PRV06', Properties(
                desc=u'Provider Organization Code', req_sit=u'N',
                data_type=(u'ID', u'3', u'3'), position=6,
                codes=[])
        ),
    ),
    Segment(
        u'LE', Properties(
            syntax='', position=u'4000', req_sit=u'S', repeat=u'1',
            desc=u'Loop Trailer'),
        Element(
            u'LE01', Properties(
                desc=u'Loop Identifier Code', req_sit=u'R',
                data_type=(u'AN', u'1', u'4'), position=1,
                codes=[u'2120'])
        ),
    ),
)
parsed_271_2115D = Loop(
    u'2115D', Properties(
        position=u'1710', looptype='', repeat=u'10', req_sit=u'S',
        desc=u'Dependent Eligibility or Benefit Additional Information'),
    Segment(
        u'III', Properties(
            syntax=u'P0102 L030405', position=u'2600', req_sit=u'S', repeat=u'1',
            desc=u'Dependent Eligibility or Benefit Additional Information'),
        Element(
            u'III01', Properties(
                desc=u'Code List Qualifier Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=1,
                codes=[u'GR', u'NI', u'ZZ'])
        ),
        Element(
            u'III02',
            Properties(
                desc=u'Industry Code', req_sit=u'S', data_type=(u'AN', u'1', u'30'),
                position=2,
                codes=[])
        ),
        Element(
            u'III03',
            Properties(
                desc=u'Code Category', req_sit=u'S', data_type=(u'ID', u'2', u'2'),
                position=3,
                codes=[u'44'])
        ),
        Element(
            u'III04', Properties(
                desc=u'Free-form Message Text', req_sit=u'S',
                data_type=(u'AN', u'1', u'264'), position=4,
                codes=[])
        ),
        Element(
            u'III05',
            Properties(
                desc=u'Quantity', req_sit=u'N', data_type=(u'R', u'1', u'15'),
                position=5,
                codes=[])
        ),
        Composite(
            u'C001', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'06',
                desc=u'Composite Unit of Measure'),
        ),
        Element(
            u'III07', Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=7,
                codes=[])
        ),
        Element(
            u'III08', Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=8,
                codes=[])
        ),
        Element(
            u'III09', Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=9,
                codes=[])
        ),
    ),
    Segment(
        u'LS',
        Properties(
            syntax='', position=u'3300', req_sit=u'S', repeat=u'1', desc=u'Loop Header'),
        Element(
            u'LS01', Properties(
                desc=u'Loop Identifier Code', req_sit=u'R',
                data_type=(u'AN', u'1', u'4'), position=1,
                codes=[u'2120'])
        ),
    ),
    parsed_271_2120D,
)
parsed_271_2110D = Loop(
    u'2110D', Properties(
        position=u'1300', looptype='', repeat=u'>1', req_sit=u'S',
        desc=u'Dependent Eligibility or Benefit Information'),
    Segment(
        u'EB', Properties(
            syntax=u'P0910', position=u'1300', req_sit=u'R', repeat=u'1',
            desc=u'Dependent Eligibility or Benefit Information'),
        Element(
            u'EB01',
            Properties(
                desc=u'Eligibility or Benefit Information Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'2'), position=1,
                codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'A', u'B',
                       u'C', u'CB', u'D', u'E', u'F', u'G', u'H', u'I', u'J', u'K',
                       u'L', u'M', u'MC', u'N', u'O', u'P', u'Q', u'R', u'S', u'T',
                       u'U', u'V', u'W', u'X', u'Y'])
        ),
        Element(
            u'EB02', Properties(
                desc=u'Coverage Level Code', req_sit=u'S',
                data_type=(u'ID', u'3', u'3'), position=2,
                codes=[u'CHD', u'DEP', u'ECH', u'EMP', u'ESP', u'FAM',
                       u'IND', u'SPC', u'SPO'])
        ),
        Element(
            u'EB03', Properties(
                desc=u'Service Type Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=3,
                codes=[u'1', u'10', u'11', u'12', u'13', u'14', u'15',
                       u'16', u'17', u'18', u'19', u'2', u'20', u'21',
                       u'22', u'23', u'24', u'25', u'26', u'27', u'28',
                       u'3', u'30', u'32', u'33', u'34', u'35', u'36',
                       u'37', u'38', u'39', u'4', u'40', u'41', u'42',
                       u'43', u'44', u'45', u'46', u'47', u'48', u'49',
                       u'5', u'50', u'51', u'52', u'53', u'54', u'55',
                       u'56', u'57', u'58', u'59', u'6', u'60', u'61',
                       u'62', u'63', u'64', u'65', u'66', u'67', u'68',
                       u'69', u'7', u'70', u'71', u'72', u'73', u'74',
                       u'75', u'76', u'77', u'78', u'79', u'8', u'80',
                       u'81', u'82', u'83', u'84', u'85', u'86', u'87',
                       u'88', u'89', u'9', u'90', u'91', u'92', u'93',
                       u'94', u'95', u'96', u'97', u'98', u'99', u'A0',
                       u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7',
                       u'A8', u'A9', u'AA', u'AB', u'AC', u'AD', u'AE',
                       u'AF', u'AG', u'AH', u'AI', u'AJ', u'AK', u'AL',
                       u'AM', u'AN', u'AO', u'AQ', u'AR', u'B1', u'B2',
                       u'B3', u'BA', u'BB', u'BC', u'BD', u'BE', u'BF',
                       u'BG', u'BH', u'BI', u'BJ', u'BK', u'BL', u'BM',
                       u'BN', u'BP', u'BQ', u'BR', u'BS', u'BT', u'BU',
                       u'BV', u'BW', u'BX', u'BY', u'BZ', u'C1', u'CA',
                       u'CB', u'CC', u'CD', u'CE', u'CF', u'CG', u'CH',
                       u'CI', u'CJ', u'CK', u'CL', u'CM', u'CN', u'CO',
                       u'CP', u'CQ', u'DG', u'DM', u'DS', u'GF', u'GN',
                       u'GY', u'IC', u'MH', u'NI', u'ON', u'PT', u'PU',
                       u'RN', u'RT', u'TC', u'TN', u'UC'])
        ),
        Element(
            u'EB04', Properties(
                desc=u'Insurance Type Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=4,
                codes=[u'12', u'13', u'14', u'15', u'16', u'41', u'42',
                       u'43', u'47', u'AP', u'C1', u'CO', u'CP', u'D',
                       u'DB', u'EP', u'FF', u'GP', u'HM', u'HN', u'HS',
                       u'IN', u'IP', u'LC', u'LD', u'LI', u'LT', u'MA',
                       u'MB', u'MC', u'MH', u'MI', u'MP', u'OT', u'PE',
                       u'PL', u'PP', u'PR', u'PS', u'QM', u'RP', u'SP',
                       u'TF', u'WC', u'WU'])
        ),
        Element(
            u'EB05', Properties(
                desc=u'Plan Coverage Description', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=5,
                codes=[])
        ),
        Element(
            u'EB06', Properties(
                desc=u'Time Period Qualifier', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=6,
                codes=[u'13', u'21', u'22', u'23', u'24', u'25', u'26',
                       u'27', u'28', u'29', u'30', u'31', u'32', u'33',
                       u'34', u'35', u'36', u'6', u'7'])
        ),
        Element(
            u'EB07',
            Properties(
                desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R', u'1', u'18'),
                position=7,
                codes=[])
        ),
        Element(
            u'EB08', Properties(
                desc=u'Percentage as Decimal', req_sit=u'S',
                data_type=(u'R', u'1', u'10'), position=8,
                codes=[])
        ),
        Element(
            u'EB09', Properties(
                desc=u'Quantity Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=9,
                codes=[u'8H', u'99', u'CA', u'CE', u'D3', u'DB', u'DY',
                       u'HS', u'LA', u'LE', u'M2', u'MN', u'P6', u'QA',
                       u'S7', u'S8', u'VS', u'YY'])
        ),
        Element(
            u'EB10',
            Properties(
                desc=u'Quantity', req_sit=u'S', data_type=(u'R', u'1', u'15'),
                position=10,
                codes=[])
        ),
        Element(
            u'EB11', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'1'), position=11,
                codes=[u'N', u'U', u'Y'])
        ),
        Element(
            u'EB12', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'1'), position=12,
                codes=[u'N', u'U', u'W', u'Y'])
        ),
        Composite(
            u'C003', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'13',
                desc=u'Composite Medical Procedure Identifier'),
            Element(
                u'EB13-01',
                Properties(
                    desc=u'Product/Service ID Qualifier', req_sit=u'R',
                    data_type=(u'ID', u'2', u'2'), position=0,
                    codes=[u'AD', u'CJ', u'HC', u'ID', u'IV', u'N4', u'ZZ'])
            ),
            Element(
                u'EB13-02', Properties(
                    desc=u'Product/Service ID', req_sit=u'R',
                    data_type=(u'AN', u'1', u'48'), position=1,
                    codes=[])
            ),
            Element(
                u'EB13-03', Properties(
                    desc=u'Procedure Modifier', req_sit=u'S',
                    data_type=(u'AN', u'2', u'2'), position=2,
                    codes=[])
            ),
            Element(
                u'EB13-04', Properties(
                    desc=u'Procedure Modifier', req_sit=u'S',
                    data_type=(u'AN', u'2', u'2'), position=3,
                    codes=[])
            ),
            Element(
                u'EB13-05', Properties(
                    desc=u'Procedure Modifier', req_sit=u'S',
                    data_type=(u'AN', u'2', u'2'), position=4,
                    codes=[])
            ),
            Element(
                u'EB13-06', Properties(
                    desc=u'Procedure Modifier', req_sit=u'S',
                    data_type=(u'AN', u'2', u'2'), position=5,
                    codes=[])
            ),
            Element(
                u'EB13-07', Properties(
                    desc=u'Description', req_sit=u'N',
                    data_type=(u'AN', u'1', u'80'), position=6,
                    codes=[])
            ),
            Element(
                u'EB13-08', Properties(
                    desc=u'Product/Service ID', req_sit=u'S',
                    data_type=(u'AN', u'1', u'48'), position=7,
                    codes=[])
            ),
        ),
        Composite(
            u'C004', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'14',
                desc=u'Composite Diagnosis Code Pointer'),
            Element(
                u'EB14-01', Properties(
                    desc=u'Diagnosis Code Pointer', req_sit=u'R',
                    data_type=(u'N0', u'1', u'2'), position=0,
                    codes=[])
            ),
            Element(
                u'EB14-02', Properties(
                    desc=u'Diagnosis Code Pointer', req_sit=u'S',
                    data_type=(u'N0', u'1', u'2'), position=1,
                    codes=[])
            ),
            Element(
                u'EB14-03', Properties(
                    desc=u'Diagnosis Code Pointer', req_sit=u'S',
                    data_type=(u'N0', u'1', u'2'), position=2,
                    codes=[])
            ),
            Element(
                u'EB14-04', Properties(
                    desc=u'Diagnosis Code Pointer', req_sit=u'S',
                    data_type=(u'N0', u'1', u'2'), position=3,
                    codes=[])
            ),
        ),
    ),
    Segment(
        u'HSD', Properties(
            syntax=u'P0102 C0605', position=u'1350', req_sit=u'S', repeat=u'9',
            desc=u'Health Care Services Delivery'),
        Element(
            u'HSD01', Properties(
                desc=u'Quantity Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=1,
                codes=[u'DY', u'FL', u'HS', u'MN', u'VS'])
        ),
        Element(
            u'HSD02',
            Properties(
                desc=u'Quantity', req_sit=u'S', data_type=(u'R', u'1', u'15'),
                position=2,
                codes=[])
        ),
        Element(
            u'HSD03', Properties(
                desc=u'Unit or Basis for Measurement Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'DA', u'MO', u'VS', u'WK', u'YR'])
        ),
        Element(
            u'HSD04', Properties(
                desc=u'Sample Selection Modulus', req_sit=u'S',
                data_type=(u'R', u'1', u'6'), position=4,
                codes=[])
        ),
        Element(
            u'HSD05', Properties(
                desc=u'Time Period Qualifier', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=5,
                codes=[u'21', u'22', u'23', u'24', u'25', u'26', u'27',
                       u'28', u'29', u'30', u'31', u'32', u'33', u'34',
                       u'35', u'6', u'7'])
        ),
        Element(
            u'HSD06', Properties(
                desc=u'Number of Periods', req_sit=u'S',
                data_type=(u'N0', u'1', u'3'), position=6,
                codes=[])
        ),
        Element(
            u'HSD07',
            Properties(
                desc=u'Ship/Delivery or Calendar Pattern Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'2'), position=7,
                codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'A',
                       u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'J', u'K', u'L',
                       u'M', u'N', u'O', u'P', u'Q', u'R', u'S', u'SG', u'SL', u'SP',
                       u'SX', u'SY', u'SZ', u'T', u'U', u'V', u'W', u'X', u'Y'])
        ),
        Element(
            u'HSD08', Properties(
                desc=u'Ship/Delivery Pattern Time Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'1'), position=8,
                codes=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'Y'])
        ),
    ),
    Segment(
        u'REF', Properties(
            syntax=u'R0203', position=u'1400', req_sit=u'S', repeat=u'9',
            desc=u'Dependent Additional Identification'),
        Element(
            u'REF01', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'18', u'1L', u'1W', u'49', u'6P', u'9F', u'ALS',
                       u'CLI', u'F6', u'FO', u'G1', u'IG', u'N6', u'NQ'])
        ),
        Element(
            u'REF02', Properties(
                desc=u'Reference Identification', req_sit=u'R',
                data_type=(u'AN', u'1', u'50'), position=2,
                codes=[])
        ),
        Element(
            u'REF03',
            Properties(
                desc=u'Description', req_sit=u'S', data_type=(u'AN', u'1', u'80'),
                position=3,
                codes=[])
        ),
        Composite(
            u'C040', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'04',
                desc=u'Reference Identifier'),
        ),
    ),
    Segment(
        u'DTP', Properties(
            syntax='', position=u'1500', req_sit=u'S', repeat=u'20',
            desc=u'Dependent Eligibility/Benefit Date'),
        Element(
            u'DTP01', Properties(
                desc=u'Date/Time Qualifier', req_sit=u'R',
                data_type=(u'ID', u'3', u'3'), position=1,
                codes=[u'096', u'193', u'194', u'198', u'290', u'291',
                       u'292', u'295', u'304', u'307', u'318', u'346',
                       u'348', u'349', u'356', u'357', u'435', u'472',
                       u'636', u'771'])
        ),
        Element(
            u'DTP02', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=2,
                codes=[u'D8', u'RD8'])
        ),
        Element(
            u'DTP03', Properties(
                desc=u'Date Time Period', req_sit=u'R',
                data_type=(u'AN', u'1', u'35'), position=3,
                codes=[])
        ),
    ),
    Segment(
        u'AAA', Properties(
            syntax='', position=u'1600', req_sit=u'S', repeat=u'9',
            desc=u'Dependent Request Validation'),
        Element(
            u'AAA01', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'N', u'Y'])
        ),
        Element(
            u'AAA02', Properties(
                desc=u'Agency Qualifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'AAA03', Properties(
                desc=u'Reject Reason Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'15', u'33', u'52', u'53', u'54', u'55', u'56',
                       u'57', u'60', u'61', u'62', u'63', u'69', u'70',
                       u'98', u'AA', u'AE', u'AF', u'AG', u'AO', u'CI',
                       u'E8', u'IA', u'MA'])
        ),
        Element(
            u'AAA04', Properties(
                desc=u'Follow-up Action Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'C', u'N', u'R', u'W', u'X', u'Y'])
        ),
    ),
    parsed_271_2115D,
    Segment(
        u'MSG', Properties(
            syntax=u'C0302', position=u'2500', req_sit=u'S', repeat=u'10',
            desc=u'Message Text'),
        Element(
            u'MSG01', Properties(
                desc=u'Free-form Message Text', req_sit=u'R',
                data_type=(u'AN', u'1', u'264'), position=1,
                codes=[])
        ),
        Element(
            u'MSG02', Properties(
                desc=u'Printer Carriage Control Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'MSG03',
            Properties(
                desc=u'Number', req_sit=u'N', data_type=(u'N0', u'1', u'9'),
                position=3,
                codes=[])
        ),
    ), Segment(
        u'III', Properties(
            syntax=u'P0102 L030405', position=u'2600', req_sit=u'S',
            repeat=u'1',
            desc=u'Dependent Eligibility or Benefit Additional '
                 u'Information'),
        Element(
            u'III01',
            Properties(
                desc=u'Code List Qualifier Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=1,
                codes=[u'GR', u'NI', u'ZZ'])
        ),
        Element(
            u'III02', Properties(
                desc=u'Industry Code', req_sit=u'S',
                data_type=(u'AN', u'1', u'30'), position=2,
                codes=[])
        ),
        Element(
            u'III03', Properties(
                desc=u'Code Category', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'44'])
        ),
        Element(
            u'III04', Properties(
                desc=u'Free-form Message Text', req_sit=u'S',
                data_type=(u'AN', u'1', u'264'), position=4,
                codes=[])
        ),
        Element(
            u'III05', Properties(
                desc=u'Quantity', req_sit=u'N',
                data_type=(u'R', u'1', u'15'), position=5,
                codes=[])
        ),
        Composite(
            u'C001', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'06',
                desc=u'Composite Unit of Measure'),
        ),
        Element(
            u'III07',
            Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=7,
                codes=[])
        ),
        Element(
            u'III08',
            Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=8,
                codes=[])
        ),
        Element(
            u'III09',
            Properties(
                desc=u'Surface/Layer/Position Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=9,
                codes=[])
        ),
    ),
)
parsed_271_2100D = Loop(
    u'2100D',
    Properties(
        position=u'0300', looptype='', repeat=u'1', req_sit=u'R', desc=u'Dependent Name'),
    Segment(
        u'NM1',
        Properties(
            syntax=u'P0809 C1110 C1203', position=u'0300', req_sit=u'R', repeat=u'1',
            desc=u'Dependent Name'),
        Element(
            u'NM101', Properties(
                desc=u'Entity Identifier Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'03'])
        ),
        Element(
            u'NM102', Properties(
                desc=u'Entity Type Qualifier', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=2,
                codes=[u'1'])
        ),
        Element(
            u'NM103', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'S',
                data_type=(u'AN', u'1', u'60'), position=3,
                codes=[])
        ),
        Element(
            u'NM104',
            Properties(
                desc=u'Name First', req_sit=u'S', data_type=(u'AN', u'1', u'35'),
                position=4,
                codes=[])
        ),
        Element(
            u'NM105',
            Properties(
                desc=u'Name Middle', req_sit=u'S', data_type=(u'AN', u'1', u'25'),
                position=5,
                codes=[])
        ),
        Element(
            u'NM106',
            Properties(
                desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN', u'1', u'10'),
                position=6,
                codes=[])
        ),
        Element(
            u'NM107',
            Properties(
                desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN', u'1', u'10'),
                position=7,
                codes=[])
        ),
        Element(
            u'NM108', Properties(
                desc=u'Identification Code Qualifier', req_sit=u'N',
                data_type=(u'ID', u'1', u'2'), position=8,
                codes=[])
        ),
        Element(
            u'NM109', Properties(
                desc=u'Identification Code', req_sit=u'N',
                data_type=(u'AN', u'2', u'80'), position=9,
                codes=[])
        ),
        Element(
            u'NM110', Properties(
                desc=u'Entity Relationship Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=10,
                codes=[])
        ),
        Element(
            u'NM111', Properties(
                desc=u'Entity Identifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'3'), position=11,
                codes=[])
        ),
        Element(
            u'NM112', Properties(
                desc=u'Name Last or Organization Name', req_sit=u'N',
                data_type=(u'AN', u'1', u'60'), position=12,
                codes=[])
        ),
    ),
    Segment(
        u'REF', Properties(
            syntax=u'R0203', position=u'0400', req_sit=u'S', repeat=u'9',
            desc=u'Dependent Additional Identification'),
        Element(
            u'REF01', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'18', u'1L', u'1W', u'49', u'6P', u'CE', u'CT',
                       u'EA', u'EJ', u'F6', u'GH', u'HJ', u'IF', u'IG',
                       u'MRC', u'N6', u'NQ', u'Q4', u'SY', u'Y4'])
        ),
        Element(
            u'REF02', Properties(
                desc=u'Reference Identification', req_sit=u'R',
                data_type=(u'AN', u'1', u'50'), position=2,
                codes=[])
        ),
        Element(
            u'REF03',
            Properties(
                desc=u'Description', req_sit=u'S', data_type=(u'AN', u'1', u'80'),
                position=3,
                codes=[])
        ),
        Composite(
            u'C040', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'04',
                desc=u'Reference Identifier'),
        ),
    ),
    Segment(
        u'N3', Properties(
            syntax='', position=u'0600', req_sit=u'S', repeat=u'1',
            desc=u'Dependent Address'),
        Element(
            u'N301', Properties(
                desc=u'Address Information', req_sit=u'R',
                data_type=(u'AN', u'1', u'55'), position=1,
                codes=[])
        ),
        Element(
            u'N302', Properties(
                desc=u'Address Information', req_sit=u'S',
                data_type=(u'AN', u'1', u'55'), position=2,
                codes=[])
        ),
    ),
    Segment(
        u'N4',
        Properties(
            syntax=u'E0207 C0605 C0704', position=u'0700', req_sit=u'S', repeat=u'1',
            desc=u'Dependent City, State, ZIP Code'),
        Element(
            u'N401',
            Properties(
                desc=u'City Name', req_sit=u'R', data_type=(u'AN', u'2', u'30'),
                position=1,
                codes=[])
        ),
        Element(
            u'N402', Properties(
                desc=u'State or Province Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'N403',
            Properties(
                desc=u'Postal Code', req_sit=u'S', data_type=(u'ID', u'3', u'15'),
                position=3,
                codes=[])
        ),
        Element(
            u'N404',
            Properties(
                desc=u'Country Code', req_sit=u'S', data_type=(u'ID', u'2', u'3'),
                position=4,
                codes=[])
        ),
        Element(
            u'N405', Properties(
                desc=u'Location Qualifier', req_sit=u'N',
                data_type=(u'ID', u'1', u'2'), position=5,
                codes=[])
        ),
        Element(
            u'N406', Properties(
                desc=u'Location Identifier', req_sit=u'N',
                data_type=(u'AN', u'1', u'30'), position=6,
                codes=[])
        ),
        Element(
            u'N407', Properties(
                desc=u'Country Subdivision Code', req_sit=u'S',
                data_type=(u'ID', u'1', u'3'), position=7,
                codes=[])
        ),
    ),
    Segment(
        u'AAA', Properties(
            syntax='', position=u'0850', req_sit=u'S', repeat=u'9',
            desc=u'Dependent Request Validation'),
        Element(
            u'AAA01', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'N', u'Y'])
        ),
        Element(
            u'AAA02', Properties(
                desc=u'Agency Qualifier Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[])
        ),
        Element(
            u'AAA03', Properties(
                desc=u'Reject Reason Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=3,
                codes=[u'15', u'35', u'42', u'43', u'45', u'47', u'48',
                       u'49', u'51', u'52', u'56', u'57', u'58', u'60',
                       u'61', u'62', u'63', u'64', u'65', u'66', u'67',
                       u'68', u'71', u'77'])
        ),
        Element(
            u'AAA04', Properties(
                desc=u'Follow-up Action Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'C', u'N', u'R', u'S', u'W', u'X', u'Y'])
        ),
    ),
    Segment(
        u'PRV', Properties(
            syntax=u'P0203', position=u'0900', req_sit=u'S', repeat=u'1',
            desc=u'Provider Information'),
        Element(
            u'PRV01',
            Properties(
                desc=u'Provider Code', req_sit=u'R', data_type=(u'ID', u'1', u'3'),
                position=1,
                codes=[u'AD', u'AT', u'BI', u'CO', u'CV', u'H', u'HH', u'LA', u'OT',
                       u'P1', u'P2', u'PC', u'PE', u'R', u'RF', u'SK', u'SU'])
        ),
        Element(
            u'PRV02', Properties(
                desc=u'Reference Identification Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=2,
                codes=[u'PXC'])
        ),
        Element(
            u'PRV03', Properties(
                desc=u'Reference Identification', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=3,
                codes=[])
        ),
        Element(
            u'PRV04', Properties(
                desc=u'State or Province Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=4,
                codes=[])
        ),
        Composite(
            u'C035', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'05',
                desc=u'Provider Specialty Information'),
        ),
        Element(
            u'PRV06', Properties(
                desc=u'Provider Organization Code', req_sit=u'N',
                data_type=(u'ID', u'3', u'3'), position=6,
                codes=[])
        ),
    ),
    Segment(
        u'DMG',
        Properties(
            syntax=u'P0102 P1011 C1105', position=u'1000', req_sit=u'S', repeat=u'1',
            desc=u'Dependent Demographic Information'),
        Element(
            u'DMG01', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=1,
                codes=[u'D8'])
        ),
        Element(
            u'DMG02', Properties(
                desc=u'Date Time Period', req_sit=u'S',
                data_type=(u'AN', u'1', u'35'), position=2,
                codes=[])
        ),
        Element(
            u'DMG03',
            Properties(
                desc=u'Gender Code', req_sit=u'S', data_type=(u'ID', u'1', u'1'),
                position=3,
                codes=[u'F', u'M', u'U'])
        ),
        Element(
            u'DMG04', Properties(
                desc=u'Marital Status Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[])
        ),
        Composite(
            u'C056', Properties(
                req_sit=u'N', repeat=u'10', refdes='', seq=u'05',
                desc=u'Composite Race or Ethnicity Information'),
        ),
        Element(
            u'DMG06', Properties(
                desc=u'Citizenship Status Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'2'), position=6,
                codes=[])
        ),
        Element(
            u'DMG07',
            Properties(
                desc=u'Country Code', req_sit=u'N', data_type=(u'ID', u'2', u'3'),
                position=7,
                codes=[])
        ),
        Element(
            u'DMG08', Properties(
                desc=u'Basis of Verification Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'2'), position=8,
                codes=[])
        ),
        Element(
            u'DMG09',
            Properties(
                desc=u'Quantity', req_sit=u'N', data_type=(u'R', u'1', u'15'),
                position=9,
                codes=[])
        ),
        Element(
            u'DMG10', Properties(
                desc=u'Code List Qualifier Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'3'), position=10,
                codes=[])
        ),
        Element(
            u'DMG11',
            Properties(
                desc=u'Industry Code', req_sit=u'N', data_type=(u'AN', u'1', u'30'),
                position=11,
                codes=[])
        ),
    ),
    Segment(
        u'INS', Properties(
            syntax=u'P1112', position=u'1100', req_sit=u'S', repeat=u'1',
            desc=u'Dependent Relationship'),
        Element(
            u'INS01', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'N'])
        ),
        Element(
            u'INS02', Properties(
                desc=u'Individual Relationship Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[u'01', u'19', u'20', u'21', u'39', u'40', u'53',
                       u'G8'])
        ),
        Element(
            u'INS03', Properties(
                desc=u'Maintenance Type Code', req_sit=u'S',
                data_type=(u'ID', u'3', u'3'), position=3,
                codes=[u'001'])
        ),
        Element(
            u'INS04', Properties(
                desc=u'Maintenance Reason Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=4,
                codes=[u'25'])
        ),
        Element(
            u'INS05', Properties(
                desc=u'Benefit Status Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=5,
                codes=[])
        ),
        Composite(
            u'C052', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'06',
                desc=u'Medicare Status Code'),
        ),
        Element(
            u'INS07', Properties(
                desc=u'Consolidated Omnibus Budget Reconciliation Act (COBRA) Qualifying',
                req_sit=u'N', data_type=(u'ID', u'1', u'2'), position=7,
                codes=[])
        ),
        Element(
            u'INS08', Properties(
                desc=u'Employment Status Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=8,
                codes=[])
        ),
        Element(
            u'INS09', Properties(
                desc=u'Student Status Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=9,
                codes=[])
        ),
        Element(
            u'INS10', Properties(
                desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=10,
                codes=[])
        ),
        Element(
            u'INS11', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                data_type=(u'ID', u'2', u'3'), position=11,
                codes=[])
        ),
        Element(
            u'INS12', Properties(
                desc=u'Date Time Period', req_sit=u'N',
                data_type=(u'AN', u'1', u'35'), position=12,
                codes=[])
        ),
        Element(
            u'INS13', Properties(
                desc=u'Confidentiality Code', req_sit=u'N',
                data_type=(u'ID', u'1', u'1'), position=13,
                codes=[])
        ),
        Element(
            u'INS14',
            Properties(
                desc=u'City Name', req_sit=u'N', data_type=(u'AN', u'2', u'30'),
                position=14,
                codes=[])
        ),
        Element(
            u'INS15', Properties(
                desc=u'State or Province Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=15,
                codes=[])
        ),
        Element(
            u'INS16',
            Properties(
                desc=u'Country Code', req_sit=u'N', data_type=(u'ID', u'2', u'3'),
                position=16,
                codes=[])
        ),
        Element(
            u'INS17',
            Properties(
                desc=u'Number', req_sit=u'S', data_type=(u'N0', u'1', u'9'),
                position=17,
                codes=[])
        ),
    ),
    Segment(
        u'HI', Properties(
            syntax='', position=u'1150', req_sit=u'S', repeat=u'1',
            desc=u'Dependent Health Care Diagnosis Code'),
        Composite(
            u'C022', Properties(
                req_sit=u'R', repeat='', refdes='', seq=u'01',
                desc=u'Health Care Code Information'),
            Element(
                u'HI01-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABK', u'BK'])
            ),
            Element(
                u'HI01-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI01-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI01-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI01-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI01-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI01-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI01-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI01-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'02',
                desc=u'Health Care Code Information'),
            Element(
                u'HI02-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI02-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI02-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI02-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI02-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI02-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI02-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI02-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI02-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'03',
                desc=u'Health Care Code Information'),
            Element(
                u'HI03-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI03-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI03-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI03-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI03-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI03-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI03-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI03-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI03-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'04',
                desc=u'Health Care Code Information'),
            Element(
                u'HI04-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI04-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI04-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI04-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI04-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI04-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI04-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI04-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI04-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'05',
                desc=u'Health Care Code Information'),
            Element(
                u'HI05-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI05-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI05-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI05-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI05-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI05-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI05-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI05-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI05-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'06',
                desc=u'Health Care Code Information'),
            Element(
                u'HI06-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI06-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI06-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI06-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI06-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI06-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI06-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI06-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI06-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'07',
                desc=u'Health Care Code Information'),
            Element(
                u'HI07-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI07-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI07-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI07-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI07-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI07-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI07-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI07-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI07-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'S', repeat='', refdes='', seq=u'08',
                desc=u'Health Care Code Information'),
            Element(
                u'HI08-01', Properties(
                    desc=u'Code List Qualifier Code', req_sit=u'R',
                    data_type=(u'ID', u'1', u'3'), position=0,
                    codes=[u'ABF', u'BF'])
            ),
            Element(
                u'HI08-02', Properties(
                    desc=u'Industry Code', req_sit=u'R',
                    data_type=(u'AN', u'1', u'30'), position=1,
                    codes=[])
            ),
            Element(
                u'HI08-03',
                Properties(
                    desc=u'Date Time Period Format Qualifier', req_sit=u'N',
                    data_type=(u'ID', u'2', u'3'), position=2,
                    codes=[])
            ),
            Element(
                u'HI08-04', Properties(
                    desc=u'Date Time Period', req_sit=u'N',
                    data_type=(u'AN', u'1', u'35'), position=3,
                    codes=[])
            ),
            Element(
                u'HI08-05', Properties(
                    desc=u'Monetary Amount', req_sit=u'N',
                    data_type=(u'R', u'1', u'18'), position=4,
                    codes=[])
            ),
            Element(
                u'HI08-06', Properties(
                    desc=u'Quantity', req_sit=u'N',
                    data_type=(u'R', u'1', u'15'), position=5,
                    codes=[])
            ),
            Element(
                u'HI08-07', Properties(
                    desc=u'Version Identifier', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=6,
                    codes=[])
            ),
            Element(
                u'HI08-08', Properties(
                    desc=u'Industry Code', req_sit=u'N',
                    data_type=(u'AN', u'1', u'30'), position=7,
                    codes=[])
            ),
            Element(
                u'HI08-09',
                Properties(
                    desc=u'Yes/No Condition or Response Code', req_sit=u'N',
                    data_type=(u'ID', u'1', u'1'), position=8,
                    codes=[])
            ),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'09',
                desc=u'Health Care Code Information'),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'10',
                desc=u'Health Care Code Information'),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'11',
                desc=u'Health Care Code Information'),
        ),
        Composite(
            u'C022', Properties(
                req_sit=u'N', repeat='', refdes='', seq=u'12',
                desc=u'Health Care Code Information'),
        ),
    ),
    Segment(
        u'DTP', Properties(
            syntax='', position=u'1200', req_sit=u'S', repeat=u'9',
            desc=u'Dependent Date'),
        Element(
            u'DTP01', Properties(
                desc=u'Date/Time Qualifier', req_sit=u'R',
                data_type=(u'ID', u'3', u'3'), position=1,
                codes=[u'096', u'102', u'152', u'291', u'307', u'318',
                       u'340', u'341', u'342', u'343', u'346', u'347',
                       u'356', u'357', u'382', u'435', u'442', u'458',
                       u'472', u'539', u'540', u'636', u'771'])
        ),
        Element(
            u'DTP02', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'R',
                data_type=(u'ID', u'2', u'3'), position=2,
                codes=[u'D8', u'RD8'])
        ),
        Element(
            u'DTP03', Properties(
                desc=u'Date Time Period', req_sit=u'R',
                data_type=(u'AN', u'1', u'35'), position=3,
                codes=[])
        ),
    ),
    Segment(
        u'MPI', Properties(
            syntax=u'P0607', position=u'1275', req_sit=u'S', repeat=u'1',
            desc=u'Dependent Military Personnel Information'),
        Element(
            u'MPI01', Properties(
                desc=u'Information Status Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=1,
                codes=[u'A', u'C', u'L', u'O', u'P', u'S', u'T'])
        ),
        Element(
            u'MPI02', Properties(
                desc=u'Employment Status Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[u'AE', u'AO', u'AS', u'AT', u'AU', u'CC', u'DD',
                       u'HD', u'IR', u'LX', u'PE', u'RE', u'RM', u'RR',
                       u'RU'])
        ),
        Element(
            u'MPI03', Properties(
                desc=u'Government Service Affiliation Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=3,
                codes=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H',
                       u'I', u'J', u'K', u'L', u'M', u'N', u'O', u'Q',
                       u'R', u'S', u'U', u'W'])
        ),
        Element(
            u'MPI04',
            Properties(
                desc=u'Description', req_sit=u'S', data_type=(u'AN', u'1', u'80'),
                position=4,
                codes=[])
        ),
        Element(
            u'MPI05', Properties(
                desc=u'Military Service Rank Code', req_sit=u'S',
                data_type=(u'ID', u'2', u'2'), position=5,
                codes=[u'A1', u'A2', u'A3', u'B1', u'B2', u'C1', u'C2',
                       u'C3', u'C4', u'C5', u'C6', u'C7', u'C8', u'C9',
                       u'E1', u'F1', u'F2', u'F3', u'F4', u'G1', u'G4',
                       u'L1', u'L2', u'L3', u'L4', u'L5', u'L6', u'M1',
                       u'M2', u'M3', u'M4', u'M5', u'M6', u'P1', u'P2',
                       u'P3', u'P4', u'P5', u'R1', u'R2', u'S1', u'S2',
                       u'S3', u'S4', u'S5', u'S6', u'S7', u'S8', u'S9',
                       u'SA', u'SB', u'SC', u'T1', u'V1', u'W1'])
        ),
        Element(
            u'MPI06', Properties(
                desc=u'Date Time Period Format Qualifier', req_sit=u'S',
                data_type=(u'ID', u'2', u'3'), position=6,
                codes=[u'D8', u'RD8'])
        ),
        Element(
            u'MPI07', Properties(
                desc=u'Date Time Period', req_sit=u'S',
                data_type=(u'AN', u'1', u'35'), position=7,
                codes=[])
        ),
    ),
    parsed_271_2110D,
)
parsed_271_2000D = Loop(
    u'2000D',
    Properties(
        position=u'0150', looptype='', repeat=u'>1', req_sit=u'S', desc=u'Dependent Level'),
    Segment(
        u'HL', Properties(
            syntax='', position=u'0100', req_sit=u'R', repeat=u'1',
            desc=u'Dependent Level'),
        Element(
            u'HL01', Properties(
                desc=u'Hierarchical ID Number', req_sit=u'R',
                data_type=(u'AN', u'1', u'12'), position=1,
                codes=[])
        ),
        Element(
            u'HL02', Properties(
                desc=u'Hierarchical Parent ID Number', req_sit=u'R',
                data_type=(u'AN', u'1', u'12'), position=2,
                codes=[])
        ),
        Element(
            u'HL03', Properties(
                desc=u'Hierarchical Level Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'2'), position=3,
                codes=[u'23'])
        ),
        Element(
            u'HL04', Properties(
                desc=u'Hierarchical Child Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'1'), position=4,
                codes=[u'0'])
        ),
    ),
    Segment(
        u'TRN', Properties(
            syntax='', position=u'0200', req_sit=u'S', repeat=u'3',
            desc=u'Dependent Trace Number'),
        Element(
            u'TRN01',
            Properties(
                desc=u'Trace Type Code', req_sit=u'R', data_type=(u'ID', u'1', u'2'),
                position=1,
                codes=[u'1', u'2'])
        ),
        Element(
            u'TRN02', Properties(
                desc=u'Reference Identification', req_sit=u'R',
                data_type=(u'AN', u'1', u'50'), position=2,
                codes=[])
        ),
        Element(
            u'TRN03', Properties(
                desc=u'Originating Company Identifier', req_sit=u'R',
                data_type=(u'AN', u'10', u'10'), position=3,
                codes=[])
        ),
        Element(
            u'TRN04', Properties(
                desc=u'Reference Identification', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=4,
                codes=[])
        ),
    ),
    parsed_271_2100D,
)
parsed_271_ST_LOOP = Loop(
    u'ST_LOOP', Properties(
        position=u'0200', looptype=u'explicit', repeat=u'>1', req_sit=u'R',
        desc=u'Transaction Set Header'),
    Segment(
        u'ST', Properties(
            syntax='', position=u'0100', req_sit=u'R', repeat=u'1',
            desc=u'Transaction Set Header'),
        Element(
            u'ST01', Properties(
                desc=u'Transaction Set Identifier Code', req_sit=u'R',
                data_type=(u'ID', u'3', u'3'), position=1,
                codes=[u'271'])
        ),
        Element(
            u'ST02', Properties(
                desc=u'Transaction Set Control Number', req_sit=u'R',
                data_type=(u'AN', u'4', u'9'), position=2,
                codes=[])
        ),
        Element(
            u'ST03', Properties(
                desc=u'Implementation Convention Reference', req_sit=u'R',
                data_type=(u'AN', u'1', u'35'), position=3,
                codes=[u'005010X279A1'])
        ),
    ),
    Segment(
        u'BHT', Properties(
            syntax='', position=u'0110', req_sit=u'R', repeat=u'1',
            desc=u'Beginning of Hierarchical Transaction'),
        Element(
            u'BHT01', Properties(
                desc=u'Hierarchical Structure Code', req_sit=u'R',
                data_type=(u'ID', u'4', u'4'), position=1,
                codes=[u'0022'])
        ),
        Element(
            u'BHT02', Properties(
                desc=u'Transaction Set Purpose Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=2,
                codes=[u'06', u'11'])
        ),
        Element(
            u'BHT03', Properties(
                desc=u'Reference Identification', req_sit=u'S',
                data_type=(u'AN', u'1', u'50'), position=3,
                codes=[])
        ),
        Element(
            u'BHT04',
            Properties(
                desc=u'Date', req_sit=u'R', data_type=(u'DT', u'8', u'8'),
                position=4,
                codes=[])
        ),
        Element(
            u'BHT05',
            Properties(
                desc=u'Time', req_sit=u'R', data_type=(u'TM', u'4', u'8'),
                position=5,
                codes=[])
        ),
        Element(
            u'BHT06', Properties(
                desc=u'Transaction Type Code', req_sit=u'N',
                data_type=(u'ID', u'2', u'2'), position=6,
                codes=[])
        ),
    ),
    parsed_271_2000A,
    parsed_271_2000B,
    parsed_271_2000C,
    parsed_271_2000D,
    Segment(
        u'SE', Properties(
            syntax='', position=u'4100', req_sit=u'R', repeat=u'1',
            desc=u'Transaction Set Trailer'),
        Element(
            u'SE01', Properties(
                desc=u'Number of Included Segments', req_sit=u'R',
                data_type=(u'N0', u'1', u'10'), position=1,
                codes=[])
        ),
        Element(
            u'SE02', Properties(
                desc=u'Transaction Set Control Number', req_sit=u'R',
                data_type=(u'AN', u'4', u'9'), position=2,
                codes=[])
        ),
    ),
)
parsed_271_GS_LOOP = Loop(
    u'GS_LOOP', Properties(
        position=u'0200', looptype=u'explicit', repeat=u'>1', req_sit=u'R',
        desc=u'Functional Group Header'),
    Segment(
        u'GS', Properties(
            syntax='', position=u'0100', req_sit=u'R', repeat=u'1',
            desc=u'Functional Group Header'),
        Element(
            u'GS01', Properties(
                desc=u'Functional Identifier Code', req_sit=u'R',
                data_type=(u'ID', u'2', u'2'), position=1,
                codes=[u'HB'])
        ),
        Element(
            u'GS02', Properties(
                desc=u'Application Senders Code', req_sit=u'R',
                data_type=(u'AN', u'2', u'15'), position=2,
                codes=[])
        ),
        Element(
            u'GS03', Properties(
                desc=u'124', req_sit=u'R', data_type=(u'AN', u'2', u'15'),
                position=3,
                codes=[])
        ),
        Element(
            u'GS04', Properties(
                desc=u'Date', req_sit=u'R', data_type=(u'DT', u'8', u'8'),
                position=4,
                codes=[])
        ),
        Element(
            u'GS05', Properties(
                desc=u'Time', req_sit=u'R', data_type=(u'TM', u'4', u'8'),
                position=5,
                codes=[])
        ),
        Element(
            u'GS06', Properties(
                desc=u'Group Control Number', req_sit=u'R',
                data_type=(u'N0', u'1', u'9'), position=6,
                codes=[])
        ),
        Element(
            u'GS07', Properties(
                desc=u'Responsible Agency Code', req_sit=u'R',
                data_type=(u'ID', u'1', u'2'), position=7,
                codes=[u'X'])
        ),
        Element(
            u'GS08',
            Properties(
                desc=u'Version / Release / Industry Identifier Code', req_sit=u'R',
                data_type=(u'AN', u'1', u'12'), position=8,
                codes=[u'005010X279A1'])
        ),
    ),
    parsed_271_ST_LOOP,
    Segment(
        u'GE', Properties(
            syntax='', position=u'0300', req_sit=u'R', repeat=u'1',
            desc=u'Functional Group Trailer'),
        Element(
            u'GE01', Properties(
                desc=u'97', req_sit=u'R', data_type=(u'N0', u'1', u'6'),
                position=1,
                codes=[])
        ),
        Element(
            u'GE02', Properties(
                desc=u'Group Control Number', req_sit=u'R',
                data_type=(u'N0', u'1', u'9'), position=2,
                codes=[])
        ),
    ),
)
parsed_271_ISA_LOOP = Loop(
    u'ISA_LOOP', Properties(
        position=u'0010', looptype=u'explicit', repeat=u'>1', req_sit=u'R',
        desc=u'Interchange Control Header'),
    Segment(
        u'ISA', Properties(
            syntax='', position=u'0100', req_sit=u'R', repeat=u'1',
            desc=u'Interchange Control Header'),
        Element(
            u'ISA01',
            Properties(
                desc=u'I01', req_sit=u'R', data_type=(u'ID', u'2', u'2'),
                position=1,
                codes=[u'00', u'03'])
        ),
        Element(
            u'ISA02',
            Properties(
                desc=u'I02', req_sit=u'R', data_type=(u'AN', u'10', u'10'),
                position=2,
                codes=[])
        ),
        Element(
            u'ISA03',
            Properties(
                desc=u'I03', req_sit=u'R', data_type=(u'ID', u'2', u'2'),
                position=3,
                codes=[u'00', u'01'])
        ),
        Element(
            u'ISA04',
            Properties(
                desc=u'I04', req_sit=u'R', data_type=(u'AN', u'10', u'10'),
                position=4,
                codes=[])
        ),
        Element(
            u'ISA05',
            Properties(
                desc=u'I05', req_sit=u'R', data_type=(u'ID', u'2', u'2'),
                position=5,
                codes=[u'01', u'14', u'20', u'27', u'28', u'29', u'30', u'33',
                       u'ZZ'])
        ),
        Element(
            u'ISA06',
            Properties(
                desc=u'I06', req_sit=u'R', data_type=(u'AN', u'15', u'15'),
                position=6,
                codes=[])
        ),
        Element(
            u'ISA07',
            Properties(
                desc=u'I05', req_sit=u'R', data_type=(u'ID', u'2', u'2'),
                position=7,
                codes=[u'01', u'14', u'20', u'27', u'28', u'29', u'30', u'33',
                       u'ZZ'])
        ),
        Element(
            u'ISA08',
            Properties(
                desc=u'I07', req_sit=u'R', data_type=(u'AN', u'15', u'15'),
                position=8,
                codes=[])
        ),
        Element(
            u'ISA09',
            Properties(
                desc=u'I08', req_sit=u'R', data_type=(u'DT', u'6', u'6'),
                position=9,
                codes=[])
        ),
        Element(
            u'ISA10',
            Properties(
                desc=u'I09', req_sit=u'R', data_type=(u'TM', u'4', u'4'),
                position=10,
                codes=[])
        ),
        Element(
            u'ISA11',
            Properties(
                desc=u'I65', req_sit=u'R', data_type=(u'AN', u'1', u'1'),
                position=11,
                codes=[])
        ),
        Element(
            u'ISA12',
            Properties(
                desc=u'I11', req_sit=u'R', data_type=(u'ID', u'5', u'5'),
                position=12,
                codes=[u'00501'])
        ),
        Element(
            u'ISA13',
            Properties(
                desc=u'I12', req_sit=u'R', data_type=(u'N0', u'9', u'9'),
                position=13,
                codes=[])
        ),
        Element(
            u'ISA14',
            Properties(
                desc=u'I13', req_sit=u'R', data_type=(u'ID', u'1', u'1'),
                position=14,
                codes=[u'0', u'1'])
        ),
        Element(
            u'ISA15',
            Properties(
                desc=u'I14', req_sit=u'R', data_type=(u'ID', u'1', u'1'),
                position=15,
                codes=[u'P', u'T'])
        ),
        Element(
            u'ISA16',
            Properties(
                desc=u'I15', req_sit=u'R', data_type=(u'AN', u'1', u'1'),
                position=16,
                codes=[])
        ),
    ),
    parsed_271_GS_LOOP,
    Segment(
        u'TA1', Properties(
            syntax='', position=u'0200', req_sit=u'S', repeat=u'1',
            desc=u'Interchange Acknowledgement'),
        Element(
            u'TA101',
            Properties(
                desc=u'I12', req_sit=u'R', data_type=(u'N0', u'9', u'9'),
                position=1,
                codes=[])
        ),
        Element(
            u'TA102',
            Properties(
                desc=u'I08', req_sit=u'R', data_type=(u'DT', u'6', u'6'),
                position=2,
                codes=[])
        ),
        Element(
            u'TA103',
            Properties(
                desc=u'I09', req_sit=u'R', data_type=(u'TM', u'4', u'4'),
                position=3,
                codes=[])
        ),
        Element(
            u'TA104',
            Properties(
                desc=u'I17', req_sit=u'R', data_type=(u'ID', u'1', u'1'),
                position=4,
                codes=[u'A', u'E', u'R'])
        ),
        Element(
            u'TA105',
            Properties(
                desc=u'I18', req_sit=u'R', data_type=(u'ID', u'3', u'3'),
                position=5,
                codes=[u'000', u'001', u'002', u'003', u'004', u'005', u'006',
                       u'007', u'008', u'009', u'010', u'011', u'012', u'013',
                       u'014', u'015', u'016', u'017', u'018', u'019', u'020',
                       u'021', u'022', u'023', u'024', u'025', u'026', u'027',
                       u'028', u'029', u'030', u'031'])
        ),
    ),
    Segment(
        u'IEA', Properties(
            syntax='', position=u'0300', req_sit=u'R', repeat=u'1',
            desc=u'Interchange Control Trailer'),
        Element(
            u'IEA01',
            Properties(
                desc=u'I16', req_sit=u'R', data_type=(u'N0', u'1', u'5'),
                position=1,
                codes=[])
        ),
        Element(
            u'IEA02',
            Properties(
                desc=u'I12', req_sit=u'R', data_type=(u'N0', u'9', u'9'),
                position=2,
                codes=[])
        ),
    ),
)
parsed_271 = Message(
    u'271B1', Properties(
        desc=u'HIPAA Health Care Eligibility Benefit Response 005010X279A1 271B1'),
    parsed_271_ISA_LOOP,
)
